"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _alert = require("./alert");

var _ = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var classes = (0, _.mockClasses)(_alert.styles);
var defaultProps = {
  classes: classes,
  theme: _.theme
};
describe('<Alert />', function () {
  test('should render <div> as container', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.type();
    var expected = 'div';
    expect(actual).toBe(expected);
  });
  test('should have class alert', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.hasClass(classes.alert);
    expect(actual).toBe(true);
  });
  ['success', 'warning', 'danger'].forEach(function (modifier) {
    test("should have class ".concat(classes[modifier], " if modifier is set to ").concat(modifier), function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
        header: "header"
      }, defaultProps), "body"));
      wrapper.setProps({
        modifier: modifier
      });
      var actual = wrapper.hasClass("".concat(classes[modifier]));
      expect(actual).toBe(true);
    });
  });
  test('should render the header if provided', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.find("div.".concat(classes.header)).childAt(0).text();
    var expected = 'header';
    expect(actual).toBe(expected);
  });
  test('should render the children if provided', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.find("div.".concat(classes.body)).childAt(0).text();
    var expected = 'body';
    expect(actual).toBe(expected);
  });
  test('should close if the dismiss button is clicked', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
      header: "header"
    }, defaultProps), "body"));
    wrapper.find("button.".concat(classes.close)).simulate('click');
    var actual = wrapper.html();
    var expected = null;
    expect(actual).toBe(expected);
  });
  test('should not render the dismiss button if dismissable is set to false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({
      header: "header"
    }, defaultProps), "body"));
    wrapper.setProps({
      dismissable: false
    });
    var actual = wrapper.find("button.".concat(classes.close)).exists();
    expect(actual).toBe(false);
  });
  test('should call dismissedCallback when dismissed', function () {
    var spy = _sinon.default.spy();

    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({}, defaultProps, {
      dismissedCallback: spy
    }), "body"));
    wrapper.find("button.".concat(classes.close)).simulate('click');
    expect(spy.calledOnce).toBe(true);
  });
  test('should not call dismissedCallback when not dismissed', function () {
    var spy = _sinon.default.spy();

    (0, _enzyme.shallow)(_react.default.createElement(_alert.Component, _extends({}, defaultProps, {
      dismissedCallback: spy
    }), "body"));
    expect(spy.called).toBe(false);
  });
});