"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Component = Animate;
exports.default = exports.styles = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactJss = _interopRequireDefault(require("react-jss"));

var _classnames = _interopRequireDefault(require("classnames"));

var _reactTransitionGroup = require("react-transition-group");

var _easings = _interopRequireDefault(require("../../styles/transitions/easings"));

var _durations = _interopRequireDefault(require("../../styles/transitions/durations"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var zeroHeight = function zeroHeight() {
  return 0;
};

var getEstimatedHeight = function getEstimatedHeight(props) {
  return props.estimatedHeight;
};

var initialHeight = {
  maxHeight: zeroHeight
};
var styles = {
  height: {
    boxSizing: 'border-box',
    transitionProperty: 'max-height, height'
  },
  heightEnter: initialHeight,
  heightEnterActive: {
    maxHeight: getEstimatedHeight,
    transitionTimingFunction: function transitionTimingFunction(props) {
      return props.easingEnterFunction;
    },
    transitionDuration: function transitionDuration(props) {
      return props.enterTime;
    },
    overflow: 'hidden'
  },
  heightExit: {
    maxHeight: getEstimatedHeight,
    transitionTimingFunction: function transitionTimingFunction(props) {
      return props.easingLeaveFunction;
    },
    transitionDuration: function transitionDuration(props) {
      return props.leaveTime;
    },
    overflow: 'hidden'
  },
  heightExitActive: initialHeight
};
exports.styles = styles;

var items = function items(children, classNameProp, classNames, timeout) {
  return children.map(function (child) {
    return _react.default.createElement(_reactTransitionGroup.CSSTransition, {
      key: child.key,
      className: classNameProp,
      classNames: classNames,
      timeout: timeout
    }, _react.default.createElement("div", null, child));
  });
};

function Animate(_ref) {
  var classes = _ref.classes,
      className = _ref.className,
      children = _ref.children,
      type = _ref.type,
      enterTime = _ref.enterTime,
      leaveTime = _ref.leaveTime;
  var classNameProp = (0, _classnames.default)(classes[type], className);
  var classNames = {
    enter: classes["".concat(type, "Enter")],
    enterActive: classes["".concat(type, "EnterActive")],
    exit: classes["".concat(type, "Exit")],
    exitActive: classes["".concat(type, "ExitActive")]
  };
  var timeout = {
    enter: enterTime,
    exit: leaveTime
  };
  return _react.default.createElement(_reactTransitionGroup.TransitionGroup, null, items(_react.default.Children.toArray(children), classNameProp, classNames, timeout));
}

Animate.propTypes = {
  classes: _propTypes.default.object.isRequired,
  children: _propTypes.default.node,
  className: _propTypes.default.string,
  type: _propTypes.default.oneOf(['height']),
  enterTime: _propTypes.default.number,
  leaveTime: _propTypes.default.number,
  easingEnterFunction: _propTypes.default.string,
  easingLeaveFunction: _propTypes.default.string,
  estimatedHeight: _propTypes.default.number
};
Animate.defaultProps = {
  type: 'height',
  enterTime: _durations.default.shorter,
  leaveTime: _durations.default.shorter,
  easingEnterFunction: _easings.default.easeIn,
  easingLeaveFunction: _easings.default.easeOut,
  estimatedHeight: 500
};

var _default = (0, _reactJss.default)(styles)(Animate);

exports.default = _default;