"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _color = _interopRequireDefault(require("color"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var focusColor = function focusColor(color) {
  return (0, _color.default)(color).darken(0.1).hex();
};

var buttonModifierFn = function buttonModifierFn(variant, color, colorFocus, colorDisabled, textColorDisabled) {
  var variantDict = {
    primary: {
      background: color,
      borderColor: color,
      '&:hover': {
        background: colorFocus,
        borderColor: colorFocus
      },
      '&:disabled': {
        background: colorDisabled,
        borderColor: colorDisabled,
        color: textColorDisabled
      },
      '&:focus, &:active': {
        boxShadow: "0 0 0 2px ".concat(colorFocus)
      }
    },
    secondary: {
      color: color,
      borderColor: color,
      '&:hover': {
        color: colorFocus,
        borderColor: colorFocus
      },
      '&:disabled': {
        color: textColorDisabled,
        borderColor: colorDisabled
      },
      '&:focus, &:active': {
        boxShadow: "0 0 0 2px ".concat(colorFocus)
      }
    },
    link: {
      color: color,
      '&:hover': {
        color: colorFocus,
        textDecoration: 'underline'
      }
    }
  };
  return _objectSpread({}, variantDict[variant]);
};

var _default = function _default(theme) {
  var palette = theme.palette,
      transitions = theme.transitions,
      typography = theme.typography,
      mixins = theme.mixins;
  return {
    button: _objectSpread({}, mixins.basicBoxSizing, {
      display: 'inline-block',
      border: "2px solid ".concat(palette.cta),
      margin: 2
    }, typography.caption({
      weight: 'regular'
    }), {
      transition: transitions.create(),
      textDecoration: 'none',
      userSelect: 'none',
      textAlign: 'center',
      '& > span': {
        position: 'relative'
      },
      '&:disabled': {
        cursor: 'not-allowed'
      },
      '&:hover:not(:disabled)': {
        cursor: 'pointer'
      },
      '&:focus': {
        outline: 'none'
      }
    }),
    block: {
      display: 'block',
      width: '100%'
    },
    xs: _objectSpread({
      padding: '1px 4px 3px',
      '&$iconText': {
        paddingBottom: 3,
        paddingTop: 2
      },
      '&$icon': {
        padding: 4,
        '& svg': {
          height: 11,
          width: 11
        }
      }
    }, typography.secondary({
      weight: 'regular'
    })),
    sm: _objectSpread({
      padding: '4px 5px 5px',
      '&$iconText': {
        paddingBottom: 6,
        paddingTop: 5
      },
      '&$icon': {
        padding: 6,
        '& svg': {
          height: 13,
          width: 13
        }
      }
    }, typography.secondary({
      weight: 'regular'
    })),
    md: _objectSpread({
      padding: '8px 32px 9px',
      '&$iconText': {
        paddingBottom: 11,
        paddingTop: 10
      },
      '&$icon': {
        padding: 8,
        '& svg': {
          height: 16,
          width: 16
        }
      }
    }, typography.primary({
      weight: 'regular'
    })),
    lg: _objectSpread({
      padding: '12px 38px',
      '&$iconText': {
        paddingBottom: 13,
        paddingTop: 13
      },
      '&$icon': {
        padding: 10,
        '& svg': {
          height: 18,
          width: 18
        }
      }
    }, typography.primary({
      weight: 'regular'
    })),
    iconAbove: {
      flexDirection: 'column'
    },
    iconText: {},
    innerWrapper: {
      alignItems: 'center',
      display: 'flex',
      justifyContent: 'center'
    },
    spaceLeft: {
      marginLeft: '0.5em'
    },
    spaceAbove: {
      marginTop: 4
    },
    primary: _objectSpread({}, buttonModifierFn('primary', palette.cta, focusColor(palette.cta), palette.gray5, palette.white), {
      color: palette.white,
      '&:focus, &:active': {
        boxShadow: "0 0 0 2px ".concat(focusColor(palette.gray5))
      },
      '&.action': buttonModifierFn('primary', palette.cta, focusColor(palette.cta), palette.gray5, palette.white),
      '&.success': buttonModifierFn('primary', palette.positive, focusColor(palette.positive), palette.gray5, palette.white),
      '&.danger': buttonModifierFn('primary', palette.negative, focusColor(palette.negative), palette.gray5, palette.white)
    }),
    secondary: _objectSpread({}, buttonModifierFn('secondary', palette.cta, focusColor(palette.cta), palette.gray6, palette.gray4), {
      backgroundColor: palette.white,
      '&:hover': {
        color: (0, _color.default)(palette.gray0).darken(0.1).hex(),
        borderColor: (0, _color.default)(palette.gray4).darken(0.1).hex()
      },
      '&:disabled': {
        borderColor: palette.gray6,
        color: palette.gray4
      },
      '&:focus, &:active': {
        boxShadow: "0 0 0 2px ".concat((0, _color.default)(palette.gray4).darken(0.1).hex())
      },
      '&.action': buttonModifierFn('secondary', palette.cta, focusColor(palette.cta), palette.gray6, palette.gray4),
      '&.success': buttonModifierFn('secondary', palette.positive, focusColor(palette.positive), palette.gray6, palette.gray4),
      '&.danger': buttonModifierFn('secondary', palette.negative, focusColor(palette.negative), palette.gray6, palette.gray4)
    }),
    link: _objectSpread({}, buttonModifierFn('link', palette.cta, focusColor(palette.cta)), {
      position: 'relative',
      background: 'none',
      paddingLeft: 0,
      paddingRight: 0,
      border: '2px solid transparent',
      fontWeight: 600,
      cursor: 'pointer',
      '&::after': {
        position: 'absolute',
        content: '""',
        left: 0,
        right: 0,
        bottom: 0,
        top: 0,
        marginBottom: 3,
        transition: transitions.create()
      },
      '&:hover': {
        color: palette.gray0
      },
      '&:disabled': {
        color: palette.gray4
      },
      '&': buttonModifierFn('link', palette.cta, focusColor(palette.cta)),
      '&.action': buttonModifierFn('link', palette.cta, focusColor(palette.cta)),
      '&.success': buttonModifierFn('link', palette.positive, focusColor(palette.positive)),
      '&.warning': buttonModifierFn('link', palette.negative, focusColor(palette.negative)),
      '&.danger': buttonModifierFn('link', palette.negative, focusColor(palette.negative))
    })
  };
};

exports.default = _default;