"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _ = require("../..");

var _button = require("./button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Button />', function () {
  var classes = (0, _.mockClasses)(_button.styles);
  var wrapper;
  test('should render <button> by default', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
      classes: classes
    }, "Button"));
    expect(wrapper.type()).toBe('button');
  });
  ['primary', 'secondary', 'link'].forEach(function (variant) {
    test("should have class ".concat(classes[variant], " if variant is set to ").concat(variant), function () {
      wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
        classes: classes,
        variant: variant
      }, "Button"));
      expect(wrapper.hasClass(classes[variant])).toBe(true);
    });
  });
  ['danger', 'warning', 'success'].forEach(function (modifier) {
    test("should have class ".concat(modifier, " if modifier is set to ").concat(modifier), function () {
      wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
        classes: classes,
        modifier: modifier
      }, "Button"));
      expect(wrapper.hasClass(modifier)).toBe(true);
    });
  });
  test('should render children', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
      classes: classes
    }, "Button"));
    expect(wrapper.childAt(0).text()).toBe('Button');
  });
  test('should be disabled if prop disabled is set', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
      classes: classes,
      disabled: true
    }, "Button"));
    expect(wrapper.props().disabled).toBe(true);
  });
  test("should have class icon for an icon button", function () {
    var icon = _react.default.createElement("svg", null);

    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
      classes: classes,
      icon: icon
    }));
    expect(wrapper.hasClass(classes.icon)).toBe(true);
  });
  test("should have class iconText for a button with an icon", function () {
    var icon = _react.default.createElement("svg", null);

    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.Component, {
      classes: classes,
      icon: icon
    }, "Button"));
    expect(wrapper.hasClass(classes.iconText)).toBe(true);
  });
});