"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _deprecate = require("./deprecate");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var warnMock;
beforeEach(function () {
  warnMock = jest.fn();
  global.console.warn = warnMock;
});
var DEFAULT_MESSAGE = 'Please consult the docs for a migration guide.';
test('deprecatedComponent', function () {
  var Component = function Component() {
    return _react.default.createElement("div", null);
  };

  var DC = (0, _deprecate.deprecatedComponent)('Flag')(Component);
  (0, _enzyme.shallow)(_react.default.createElement(DC, null));
  expect(warnMock).toHaveBeenCalled();
  expect(warnMock.mock.calls[0][0]).toMatch('Flag is deprecated.');
  expect(warnMock.mock.calls[0][0]).toMatch(DEFAULT_MESSAGE);
});
test('deprecatedComponent with custom message', function () {
  var Component = function Component() {
    return _react.default.createElement("div", null);
  };

  var msg = 'Use the new Flag component instead.';
  var DC = (0, _deprecate.deprecatedComponent)('Flag2', msg)(Component);
  (0, _enzyme.shallow)(_react.default.createElement(DC, null));
  expect(warnMock).toHaveBeenCalled();
  expect(warnMock.mock.calls[0][0]).toMatch('Flag2 is deprecated.');
  expect(warnMock.mock.calls[0][0]).toMatch(msg);
});
test('deprecatedComponent should only warn once', function () {
  var Component = function Component() {
    return _react.default.createElement("div", null);
  };

  var DC = (0, _deprecate.deprecatedComponent)('Flag3')(Component);
  (0, _enzyme.shallow)(_react.default.createElement(DC, null));
  expect(warnMock).toHaveBeenCalled();
  (0, _enzyme.shallow)(_react.default.createElement(DC, null));
  expect(warnMock).toHaveBeenCalledTimes(1);
  expect(warnMock.mock.calls[0][0]).toMatch('Flag3 is deprecated.');
});
test('deprecatedProps', function () {
  var Component = function Component() {
    return _react.default.createElement("div", null);
  };

  var DC = (0, _deprecate.deprecatedProps)('Flag', [{
    prop: 'size',
    message: 'size in Flag as a number is deprecated. Use sm, md or lg instead'
  }])(Component);
  (0, _enzyme.shallow)(_react.default.createElement(DC, {
    size: 16
  }));
  expect(warnMock).toHaveBeenCalled();
  expect(warnMock.mock.calls[0][0]).toMatch('Use sm, md or lg instead');
});