"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _editableInput = require("./editable-input");

var _ = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<EditableInput />', function () {
  var classes = (0, _.mockClasses)(_editableInput.styles);
  var wrapper;
  test('should render component', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes
    }));
    expect(wrapper.type()).toBe('div');
  });
  test('should render a span and edit button as default', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes
    }));
    var readOnly = wrapper.find(".".concat(classes.readOnly));
    var buttonEdit = wrapper.find(".".concat(classes.buttonEdit));
    expect(readOnly).toHaveLength(1);
    expect(buttonEdit).toHaveLength(1);
  });
  test('should toggle editing mode when edit button is clicked', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes
    }));
    expect(wrapper.state().editing).toBe(false);
    var buttonEdit = wrapper.find(".".concat(classes.buttonEdit));
    buttonEdit.simulate('click');
    expect(wrapper.state().editing).toBe(true);
  });
  test('should render input field and buttons when in editing mode', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes
    }));
    expect(wrapper.find(".".concat(classes.form))).toHaveLength(0);
    expect(wrapper.find(".".concat(classes.buttons))).toHaveLength(0);
    wrapper.setState({
      editing: true
    });
    expect(wrapper.find(".".concat(classes.form))).toHaveLength(1);
    expect(wrapper.find(".".concat(classes.buttons))).toHaveLength(1);
  });
  test('should save the new input value when pressing submit button', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes
    }));
    wrapper.setState({
      editing: true,
      value: 'foo bar',
      originalValue: 'foo bar'
    });
    var input = wrapper.find(_.Input);
    input.simulate('change', {
      target: {
        value: 'lorem ipsum'
      }
    });
    var submitButton = wrapper.find(_.Button).first();
    submitButton.simulate('click', {
      preventDefault: function preventDefault() {}
    });
    expect(wrapper.state().value).toBe('lorem ipsum');
  });
  test('should reset to the old value when pressing cancel button', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes
    }));
    wrapper.setState({
      editing: true,
      value: 'foo bar',
      originalValue: 'foo bar'
    });
    var input = wrapper.find(_.Input);
    input.simulate('change', {
      target: {
        value: 'lorem ipsum'
      }
    });
    var cancelButton = wrapper.find(_.Button).last();
    cancelButton.simulate('click', {
      preventDefault: function preventDefault() {}
    });
    expect(wrapper.state().value).toBe('foo bar');
  });
  test('should display ****, when props is sensitive', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes,
      sensitive: true
    }));
    expect(wrapper.state().value).toBe('****');
  });
  test('should display sensitivePlaceholder value instead of default ****, when props is sensitive', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes,
      sensitivePlaceholder: "xxxx",
      sensitive: true
    }));
    expect(wrapper.state().value).toBe('xxxx');
  });
  test('should toggle editing mode with cleared input, when edit button is clicked and props is sensitive', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_editableInput.Component, {
      classes: classes,
      sensitive: true
    }));
    expect(wrapper.state().editing).toBe(false);
    var buttonEdit = wrapper.find(".".concat(classes.buttonEdit));
    buttonEdit.simulate('click');
    expect(wrapper.state().editing).toBe(true);
    expect(wrapper.state().value).toBe('');
  });
});