"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _nativeInput = _interopRequireDefault(require("./native-input"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var noop = function noop() {};

var defaultProps = {
  type: 'text',
  onFocus: noop,
  onBlur: noop,
  onChange: noop
};

var renderComponent = function renderComponent(props) {
  return (0, _enzyme.shallow)(_react.default.createElement(_nativeInput.default, _extends({}, defaultProps, props)));
};

describe('<NativeInput />', function () {
  test('has class input__element', function () {
    var wrapper = renderComponent();
    expect(wrapper.hasClass('input__element')).toBe(true);
  });
  test('has class input__element--text when type is "text"', function () {
    var wrapper = renderComponent({
      type: 'text'
    });
    expect(wrapper.hasClass('input__element--text')).toBe(true);
  });
  test('appends custom className', function () {
    var customClass = 'custom-class';
    var wrapper = renderComponent({
      className: customClass
    });
    expect(wrapper.hasClass(customClass)).toBe(true);
    expect(wrapper.hasClass('input__element')).toBe(true);
    expect(wrapper.hasClass('input__element--text')).toBe(true);
  });
  test('renders an input when type is not textarea', function () {
    var wrapper = renderComponent();
    expect(wrapper.type()).toBe('input');
  });
  test('renders an textarea when type is textarea', function () {
    var wrapper = renderComponent({
      type: 'textarea'
    });
    expect(wrapper.type()).toBe('textarea');
  });
  test('sets placeholder to placeholder if it is defined', function () {
    var placeholder = 'test123';
    var wrapper = renderComponent({
      placeholder: placeholder
    });
    expect(wrapper.prop('placeholder')).toBe(placeholder);
  });
  test('sets placeholder to label if placeholder is not defined', function () {
    var label = 'test123';
    var wrapper = renderComponent({
      label: label
    });
    expect(wrapper.prop('placeholder')).toBe(label);
  });
});