"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _instrumentBadge = require("./instrument-badge");

var _checkmark = _interopRequireDefault(require("../icon/icons/checkmark"));

var _exclamationPoint = _interopRequireDefault(require("../icon/icons/exclamationPoint"));

var _ = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<InstrumentBadge />', function () {
  var classes = (0, _.mockClasses)(_instrumentBadge.styles);
  var wrapper;
  test('should render <div> as container', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_instrumentBadge.Component, {
      classes: classes,
      theme: _.theme
    }));
    expect(wrapper.type()).toBe('div');
  });
  test('should adapt classes to size small', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_instrumentBadge.Component, {
      classes: classes,
      size: "sm",
      theme: _.theme
    }));
    expect(wrapper.find(".".concat(classes.sm))).toHaveLength(1);
    expect(wrapper.find(".".concat(classes.md))).toHaveLength(0);
  });
  test('should adapt classes to size medium', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_instrumentBadge.Component, {
      classes: classes,
      size: "md",
      theme: _.theme
    }));
    expect(wrapper.find(".".concat(classes.sm))).toHaveLength(0);
    expect(wrapper.find(".".concat(classes.md))).toHaveLength(1);
  });
  test('should render checkmark icon when marked as qualified', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_instrumentBadge.Component, {
      qualified: true,
      classes: classes,
      theme: _.theme
    }));
    expect(wrapper.find(_checkmark.default)).toHaveLength(1);
    expect(wrapper.find(_exclamationPoint.default)).toHaveLength(0);
  });
  test('should render ExclamationPoint icon when NOT marked as qualified', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_instrumentBadge.Component, {
      classes: classes,
      theme: _.theme
    }));
    expect(wrapper.find(_checkmark.default)).toHaveLength(0);
    expect(wrapper.find(_exclamationPoint.default)).toHaveLength(1);
  });
  test('should render instrument level and subtext', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_instrumentBadge.Component, {
      subText: "Qualified!",
      classes: classes,
      theme: _.theme
    }));
    expect(wrapper.find(".".concat(classes.subText)).text()).toBe('Qualified!');
  });
});