"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _ = require("../../..");

var _page = require("./page");

var _buttonNode = _interopRequireDefault(require("../button-node"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('<Page />', function () {
  var classes = (0, _.mockClasses)(_page.styles);
  var defaultProps = {
    classes: classes,
    isSelected: false,
    isFirst: false,
    isLast: false,
    pageNumber: 2,
    labelText: '',
    url: '',
    selectHandler: function selectHandler() {}
  };

  var shallowComponent = function shallowComponent(customProps) {
    return (0, _enzyme.shallow)(_react.default.createElement(_page.Component, _extends({}, defaultProps, customProps)));
  };

  test('should render a li element', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find("li.".concat(classes.item))).toHaveLength(1);
  });
  test('should render a li element with class itemAlwaysVisible if page is selected', function () {
    var wrapper = shallowComponent({
      isSelected: true
    });
    expect(wrapper.find("li.".concat(classes.item)).hasClass(classes.itemAlwaysVisible)).toBe(true);
  });
  test('should render a li element with class itemAlwaysVisible if page is first', function () {
    var wrapper = shallowComponent({
      isFirst: true
    });
    expect(wrapper.find("li.".concat(classes.item)).hasClass(classes.itemAlwaysVisible)).toBe(true);
  });
  test('should render a li element with class itemAlwaysVisible if page is last', function () {
    var wrapper = shallowComponent({
      isLast: true
    });
    expect(wrapper.find("li.".concat(classes.item)).hasClass(classes.itemAlwaysVisible)).toBe(true);
  });
  test('should render a ButtonNode component', function () {
    var wrapper = shallowComponent({
      isLast: true
    });
    expect(wrapper.find(_buttonNode.default)).toHaveLength(1);
  });
  test('should render disabled prop to ButtonNode component', function () {
    var wrapper = shallowComponent({
      isSelected: true
    });
    expect(wrapper.find(_buttonNode.default).props().disabled).toBe(true);
  });
  test('should not render disabled prop to ButtonNode component', function () {
    var wrapper = shallowComponent({
      isSelected: false
    });
    expect(wrapper.find(_buttonNode.default).props().disabled).toBe(false);
  });
  test('should render url prop to ButtonNode component', function () {
    var wrapper = shallowComponent({
      url: 'www.test.com'
    });
    expect(wrapper.find(_buttonNode.default).props().url).toBe('www.test.com');
  });
  test('should have getNode prop in ButtonNode component', function () {
    var testFunc = function testFunc() {
      return true;
    };

    var wrapper = shallowComponent({
      getNode: testFunc
    });
    expect(wrapper.find(_buttonNode.default).props().getNode).toBe(testFunc);
  });
  test('should have aria-label text in defaultProps', function () {
    var wrapper = shallowComponent({
      labelText: 'Go to page'
    });
    expect(wrapper.find(_buttonNode.default).props().defaultProps['aria-label']).toBe('Go to page');
  });
});