"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _ = require("../..");

var _pagination = require("./pagination");

var _stepper = _interopRequireDefault(require("./stepper"));

var _range = _interopRequireDefault(require("./range"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('<Pagination />', function () {
  var classes = (0, _.mockClasses)(_pagination.styles);
  var defaultProps = {
    classes: classes,
    total: 100,
    limit: 10,
    buttonTextPrevious: 'Previous',
    buttonTextNext: 'Next',
    urlGenerator: function urlGenerator() {
      return null;
    }
  };

  var shallowComponent = function shallowComponent(customProps) {
    return (0, _enzyme.shallow)(_react.default.createElement(_pagination.Component, _extends({}, defaultProps, customProps)));
  };

  test('should not paginate if there is only 1 page', function () {
    var wrapper = shallowComponent({
      total: 10,
      limit: 10
    });
    expect(wrapper.find("ul.".concat(classes.list))).toHaveLength(0);
  });
  test('should render a nav element', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find('nav')).toHaveLength(1);
  });
  test('should render next and previous buttons', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default)).toHaveLength(2);
  });
  test('previous button should not be clickable', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default).first().prop('disabled')).toBe(true);
  });
  test('previous button should be clickable', function () {
    var wrapper = shallowComponent({
      selected: 2
    });
    expect(wrapper.find(_stepper.default).first().prop('disabled')).toBe(false);
  });
  test('next button should not be clickable', function () {
    var wrapper = shallowComponent({
      selected: 10
    });
    expect(wrapper.find(_stepper.default).last().prop('disabled')).toBe(true);
  });
  test('next button should be clickable', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default).last().prop('disabled')).toBe(false);
  });
  test('next button should render text', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default).last().find(".".concat(classes.stepperText)).childAt(0).text()).toBe(defaultProps.buttonTextNext);
  });
  test('next button should render SVG', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default).last().find(_.Icon.ArrowRight)).toHaveLength(1);
  });
  test('previous button should render text', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default).first().find(".".concat(classes.stepperText)).childAt(0).text()).toBe(defaultProps.buttonTextPrevious);
  });
  test('previous button should render SVG', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_stepper.default).first().find(_.Icon.ArrowLeft)).toHaveLength(1);
  });
  test('should render a range of pages', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_range.default)).toHaveLength(1);
  });
  test('should increment selected in state', function () {
    var clickCallback = _sinon.default.spy();

    var wrapper = shallowComponent({
      changeHandler: clickCallback
    });
    wrapper.find(_stepper.default).last().props().clickHandler();
    expect(wrapper.state().selected).toBe(2);
  });
  test('should decrement selected in state', function () {
    var clickCallback = _sinon.default.spy();

    var wrapper = shallowComponent({
      changeHandler: clickCallback,
      selected: 2
    });
    wrapper.find(_stepper.default).first().props().clickHandler();
    expect(wrapper.state().selected).toBe(1);
  });
  test('should increment selected in state when prop changes', function () {
    var clickCallback = _sinon.default.spy();

    var selected = 1;
    var wrapper = shallowComponent({
      selected: selected,
      changeHandler: clickCallback
    });
    wrapper.setProps({
      selected: selected + 1
    });
    expect(wrapper.state().selected).toBe(selected + 1);
  });
  test('should decrement selected in state when prop changes', function () {
    var clickCallback = _sinon.default.spy();

    var selected = 2;
    var wrapper = shallowComponent({
      selected: selected,
      changeHandler: clickCallback
    });
    wrapper.setProps({
      selected: selected - 1
    });
    expect(wrapper.state().selected).toBe(selected - 1);
  });
});