"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _ = require("../../..");

var _range = require("./range");

var _page = _interopRequireDefault(require("../page"));

var _ellipsis = _interopRequireDefault(require("../ellipsis"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('<Range />', function () {
  var classes = (0, _.mockClasses)(_range.styles);
  var defaultProps = {
    classes: classes,
    anchors: 1,
    pagesCount: 10,
    selected: 1,
    selectedSiblings: 2,
    urlGenerator: function urlGenerator() {
      return null;
    }
  };

  var shallowComponent = function shallowComponent(customProps) {
    return (0, _enzyme.shallow)(_react.default.createElement(_range.Component, _extends({}, defaultProps, customProps)));
  };

  test('should render a ul element', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find("ul.".concat(classes.list))).toHaveLength(1);
  });
  test('should render 5 pages', function () {
    var wrapper = shallowComponent({
      pagesCount: 5
    });
    expect(wrapper.find(_page.default)).toHaveLength(5);
  });
  test('should render one ellipsis', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_ellipsis.default)).toHaveLength(1);
  });
  test('should render two ellipsis', function () {
    var wrapper = shallowComponent({
      selected: 5
    });
    expect(wrapper.find(_ellipsis.default)).toHaveLength(2);
  });
  test('should mark page as selected', function () {
    var wrapper = shallowComponent({
      selected: 3
    });
    expect(wrapper.find(_page.default).at(2).props().isSelected).toBe(true);
  });
  test('first page should have prop isFirst', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_page.default).first().props().isFirst).toBe(true);
  });
  test('first page should not have prop isLast', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_page.default).first().props().isLast).toBe(false);
  });
  test('last page should have prop isLast', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_page.default).last().props().isLast).toBe(true);
  });
  test('last page should not have prop isFirst', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_page.default).last().props().isFirst).toBe(false);
  });
  test('page should have false on the prop isFirst', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_page.default).at(2).props().isFirst).toBe(false);
  });
  test('page should have false on the prop isLast', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(_page.default).at(2).props().isLast).toBe(false);
  });
  test('render label text for page', function () {
    var wrapper = shallowComponent({
      selected: 2,
      pageLabelText: 'go to page',
      pageLebelSelected: 'current page'
    });
    expect(wrapper.find(_page.default).first().props().labelText).toBe('go to page 1');
  });
  test('render label text for selected page', function () {
    var wrapper = shallowComponent({
      selected: 1,
      pageLabelText: 'go to page',
      pageLabelTextSelected: 'current page'
    });
    expect(wrapper.find(_page.default).first().props().labelText).toBe('current page 1');
  });
});