"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _ = require("../..");

var _popupMenu = require("./popup-menu");

var _popupMenuItem = require("./popup-menu-item");

var _popupMenuList = _interopRequireDefault(require("./popup-menu-list"));

var _keyCodes = _interopRequireDefault(require("./keyCodes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('<PopupMenuList />', function () {
  var classes = (0, _.mockClasses)(_popupMenu.styles);
  var itemClasses = (0, _.mockClasses)(_popupMenuItem.styles);
  var props = {
    onBlur: function onBlur() {},
    onKeyDown: function onKeyDown() {},
    firstListItemRef: function firstListItemRef() {},
    yieldFocus: function yieldFocus() {},
    width: 200,
    'aria-labelledby': 'PopupMenu',
    enter: 100,
    exit: 100,
    maxHeight: 'none'
  };
  test('should not render the list if isOpen is false', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: false
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    expect(wrapper.find(_popupMenuItem.Component)).toHaveLength(0);
  });
  test('should render the list if isOpen is true', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    expect(wrapper.find(_popupMenuItem.Component)).toHaveLength(1);
  });
  test('should update focusIndex if list item is focused', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    expect(instance.focusIndex).toBe(-1);
    wrapper.find(_popupMenuItem.Component).first().prop('onFocus')();
    expect(instance.focusIndex).toBe(0);
  });
  test('should focus next item on arrow down', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    wrapper.find(_popupMenuItem.Component).first().prop('onFocus')();
    expect(instance.focusIndex).toBe(0);
    instance.onKeyDown({
      keyCode: _keyCodes.default.ARROW_DOWN,
      preventDefault: function preventDefault() {}
    });
    expect(instance.focusIndex).toBe(1);
  });
  test('should focus previous item on arrow up', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    wrapper.find(_popupMenuItem.Component).last().prop('onFocus')();
    expect(instance.focusIndex).toBe(1);
    instance.onKeyDown({
      keyCode: _keyCodes.default.ARROW_UP,
      preventDefault: function preventDefault() {}
    });
    expect(instance.focusIndex).toBe(0);
  });
  test('should wrap to first item on arrow down on last item', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    wrapper.find(_popupMenuItem.Component).last().prop('onFocus')();
    expect(instance.focusIndex).toBe(1);
    instance.onKeyDown({
      keyCode: _keyCodes.default.ARROW_DOWN,
      preventDefault: function preventDefault() {}
    });
    expect(instance.focusIndex).toBe(0);
  });
  test('should blur item on esc', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();

    var blur = _sinon.default.spy();

    instance.listItemElements = [{}, {
      focus: function focus() {},
      blur: blur
    }];
    wrapper.find(_popupMenuItem.Component).last().prop('onFocus')();
    expect(instance.focusIndex).toBe(1);
    instance.onKeyDown({
      keyCode: _keyCodes.default.ESC,
      preventDefault: function preventDefault() {}
    });
    expect(blur.calledOnce).toBe(true);
  });
  test('should not add the focus handling props to disabled children', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenuList.default, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses,
      disabled: true
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    var items = wrapper.find(_popupMenuItem.Component);
    var nonDisabledItems = items.findWhere(function (i) {
      return i.prop('listItemRef') && i.prop('onFocus') && i.prop('onKeyDown');
    });
    var disabledItems = items.findWhere(function (i) {
      return !i.prop('listItemRef') && !i.prop('onFocus') && !i.prop('onKeyDown');
    });
    expect(nonDisabledItems).toHaveLength(2);
    expect(disabledItems).toHaveLength(1);
  });
});