"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _ = require("../..");

var _popupMenu = require("./popup-menu");

var _popupMenuItem = require("./popup-menu-item");

var _popupMenuList = _interopRequireDefault(require("./popup-menu-list"));

var _keyCodes = _interopRequireDefault(require("./keyCodes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<PopupMenu />', function () {
  var classes = (0, _.mockClasses)(_popupMenu.styles);
  var itemClasses = (0, _.mockClasses)(_popupMenuItem.styles);
  var wrapper;
  test('should render <span> by default', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    expect(wrapper.type()).toBe('span');
  });
  test('should render a button and a PopupMenuList as its children', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    expect(wrapper.find("button.".concat(classes.menuButton))).toHaveLength(1);
    expect(wrapper.find(_popupMenuList.default)).toHaveLength(1);
  });
  test('renders correct amount of PopupMenuItems', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    expect(wrapper.find('PopupMenuItem')).toHaveLength(3);
  });
  test('should not be focused by default', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    expect(wrapper.state('hasFocus')).toBe(false);
  });
  test('should set hasFocus to true on toggle button focus', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    wrapper.find("button.".concat(classes.menuButton)).simulate('focus');
    expect(wrapper.state('hasFocus')).toBe(true);
  });
  test('should set hasFocus to false on toggle button blur', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    wrapper.find("button.".concat(classes.menuButton)).simulate('focus');
    wrapper.find("button.".concat(classes.menuButton)).simulate('blur');
    expect(wrapper.state('hasFocus')).toBe(false);
  });
  test('should focus first list element and prevent default on arrow down', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    }), _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));

    var focus = _sinon.default.spy();

    var preventDefault = _sinon.default.spy();

    wrapper.instance().firstListElement = {
      focus: focus
    };
    wrapper.find("button.".concat(classes.menuButton)).simulate('focus');
    wrapper.find("button.".concat(classes.menuButton)).simulate('click');
    wrapper.find("button.".concat(classes.menuButton)).simulate('keyDown', {
      preventDefault: preventDefault,
      keyCode: _keyCodes.default.ARROW_DOWN
    });
    expect(focus.calledOnce).toBe(true);
    expect(preventDefault.calledOnce).toBe(true);
  });
  test('should toggle on esc press', function () {
    var onToggle = _sinon.default.spy();

    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes,
      onToggle: onToggle
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));
    wrapper.find("button.".concat(classes.menuButton)).simulate('click');
    wrapper.find("button.".concat(classes.menuButton)).simulate('keyDown', {
      keyCode: _keyCodes.default.ESC
    });
    expect(onToggle.calledTwice).toBe(true);
  });
  test('should take focus when PopupMenuList yields focus', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_popupMenu.Component, {
      classes: classes
    }, _react.default.createElement(_popupMenuItem.Component, {
      classes: itemClasses
    })));

    var focus = _sinon.default.spy();

    wrapper.instance().buttonElement = {
      focus: focus
    };
    var yieldFocusCallback = wrapper.find(_popupMenuList.default).prop('yieldFocus');
    yieldFocusCallback();
    expect(focus.calledOnce).toBe(true);
  });
});