"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _color = _interopRequireDefault(require("color"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var focusColor = function focusColor(color) {
  return (0, _color.default)(color).darken(0.1).hex();
};

var disableColor = function disableColor(color) {
  return (0, _color.default)(color).lighten(0.7).hex();
};

var variantModifierFn = function variantModifierFn(variant, colors) {
  var background = colors.background,
      backgroundDisabled = colors.backgroundDisabled,
      borderColor = colors.borderColor,
      color = colors.color,
      colorDisabled = colors.colorDisabled;
  var variantDict = {
    primary: {
      background: background,
      borderColor: borderColor,
      borderStyle: 'solid',
      color: color,
      '&$clickable:hover:not(:disabled)': {
        background: focusColor(background),
        borderColor: focusColor(borderColor)
      },
      '&:disabled': {
        background: backgroundDisabled || disableColor(background),
        borderColor: backgroundDisabled || disableColor(borderColor),
        color: colorDisabled
      },
      '&$clickable:focus': {
        boxShadow: "0 0 0 2px ".concat(focusColor(borderColor))
      }
    }
  };
  return _objectSpread({}, variantDict[variant]);
};

var _default = function _default(theme) {
  var palette = theme.palette,
      transitions = theme.transitions,
      typography = theme.typography,
      mixins = theme.mixins;
  var sizeDict = {
    xs: _objectSpread({
      radius: 8
    }, typography.caption()),
    sm: _objectSpread({
      radius: 16
    }, typography.caption()),
    md: _objectSpread({
      radius: 20
    }, typography.secondary()),
    lg: _objectSpread({
      radius: 24
    }, typography.primary())
  };
  return {
    progressBarContainer: {
      width: '100%'
    },
    ariaProgressBar: _objectSpread({}, mixins.screenReadersOnly),
    progressBar: {
      display: 'flex',
      flexWrap: 'wrap',
      margin: function margin(_ref) {
        var size = _ref.size;
        return -sizeDict[size].radius / 2;
      }
    },
    progressStep: _objectSpread({}, typography.primary(), mixins.basicBoxSizing, {
      alignItems: 'center',
      border: 0,
      borderRadius: 0,
      borderWidth: 1,
      cursor: 'default',
      display: 'flex',
      fontSize: function fontSize(_ref2) {
        var size = _ref2.size;
        return sizeDict[size].fontSize;
      },
      fontWeight: function fontWeight(_ref3) {
        var size = _ref3.size;
        return sizeDict[size].fontWeight;
      },
      height: function height(_ref4) {
        var size = _ref4.size;
        return 2 * sizeDict[size].radius;
      },
      margin: function margin(_ref5) {
        var size = _ref5.size;
        return sizeDict[size].radius / 2;
      },
      padding: 0,
      textAlign: 'center',
      textDecoration: 'none',
      transition: transitions.create(),
      userSelect: 'none',
      width: function width(_ref6) {
        var size = _ref6.size;
        return 2 * sizeDict[size].radius;
      },
      '& > span': {
        margin: 'auto'
      }
    }),
    clickable: {
      '&:disabled': {
        cursor: 'not-allowed'
      },
      '&:hover:not(:disabled)': {
        cursor: 'pointer'
      },
      '&:focus': {
        outline: 'none'
      }
    },
    reached: {},
    active: {},
    primary: _objectSpread({}, variantModifierFn('primary', {
      background: palette.gray7,
      backgroundDisabled: palette.gray7,
      borderColor: palette.gray4,
      color: palette.gray0,
      colorDisabled: palette.gray4
    }), {
      '&$reached': variantModifierFn('primary', {
        background: palette.cta,
        borderColor: palette.cta,
        color: palette.gray7,
        colorDisabled: palette.white
      }),
      '&$active': variantModifierFn('primary', {
        background: palette.cta,
        borderColor: palette.cta
      })
    })
  };
};

exports.default = _default;