"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _ = require("../..");

var _rating = require("./rating");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var classes = (0, _.mockClasses)(_rating.styles);

var renderComponent = function renderComponent(props) {
  var defaultProps = {
    icon: _.Icon.Star,
    size: 20,
    rating: 4,
    maxRating: 6,
    classes: _objectSpread({}, classes, {
      active: 'active',
      inactive: 'inactive'
    })
  };

  var newProps = _objectSpread({}, defaultProps, props);

  return (0, _enzyme.shallow)(_react.default.createElement(_rating.Component, newProps));
};

test('Should have same number active stars as rating says', function () {
  var rating = 4;
  var component = renderComponent({
    rating: rating
  });
  var active = component.find('.active');
  var inactive = component.find('.inactive');
  expect(active).toHaveLength(4);
  expect(inactive).toHaveLength(2);
});
test('Should display a sensible default if rating is invalid', function () {
  var invalidRatings = [undefined, null, NaN, -1, 'foo'];
  invalidRatings.forEach(function (rating) {
    var component = renderComponent({
      rating: rating
    });
    expect(component.text()).toBe('–');
  });
});
test('Should display default for rating = 0 if minRating = 1', function () {
  var rating = 0;
  var minRating = 1;
  var component = renderComponent({
    rating: rating,
    minRating: minRating
  });
  expect(component.text()).toBe('–');
});
test('Should default to 0 active stars for rating = 0', function () {
  var rating = 0;
  var component = renderComponent({
    rating: rating
  });
  var active = component.find('.active');
  var inactive = component.find('.inactive');
  expect(active).toHaveLength(0);
  expect(inactive).toHaveLength(6);
});