"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _showMore = require("./show-more");

var _showMoreStyles = _interopRequireDefault(require("./show-more-styles"));

var _ = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var classes = (0, _.mockClasses)(_showMoreStyles.default);
var defaultProps = {
  children: 'Children',
  classes: classes
};
var addEventListenerSpy;
var removeEventListenerSpy;

var getWrapper = function getWrapper() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return (0, _enzyme.shallow)(_react.default.createElement(_showMore.Component, _extends({}, defaultProps, props)), {
    disableLifecycleMethods: true
  });
};

describe('<ShowMore />', function () {
  beforeEach(function () {
    addEventListenerSpy = _sinon.default.spy(window, 'addEventListener');
    removeEventListenerSpy = _sinon.default.spy(window, 'removeEventListener');
  });
  afterEach(function () {
    addEventListenerSpy.restore();
    removeEventListenerSpy.restore();
  });
  test('should render <div> as container', function () {
    var wrapper = getWrapper();
    var actual = wrapper.type();
    var expected = 'div';
    expect(actual).toBe(expected);
  });
  test('should not show button if content fits', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 500,
      clientHeight: 500
    };
    wrapper.instance().componentDidMount();
    expect(wrapper.state('isOverflowing')).toBe(false);
  });
  test('should show button if content does not fit', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().componentDidMount();
    expect(wrapper.state('isOverflowing')).toBe(true);
  });
  test('should register resize event listener on mount', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().componentDidMount();
    expect(addEventListenerSpy.args[0][0]).toBe('resize');
  });
  test('should not check if overflow when updated with same children', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };

    var checkIfOverflowingSpy = _sinon.default.spy(wrapper.instance(), 'checkIfOverflowing');

    wrapper.instance().componentDidUpdate({
      children: 'Children'
    });
    expect(checkIfOverflowingSpy.notCalled).toBe(true);
  });
  test('should check if overflow when updated with new children', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };

    var checkIfOverflowingSpy = _sinon.default.spy(wrapper.instance(), 'checkIfOverflowing');

    wrapper.instance().componentDidUpdate({
      children: 'new child'
    });
    expect(checkIfOverflowingSpy.calledOnce).toBe(true);
  });
  test('should deregister resize event listener on unmount', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().componentWillUnmount();
    expect(removeEventListenerSpy.args[0][0]).toBe('resize');
  });
  test('should set showMoreClicked to true when show more button is clicked', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().handleShowMore();
    expect(wrapper.state('showMoreClicked')).toBe(true);
  });
  test('should call user supplied onShowMore when show more button is clicked', function () {
    var onShowMore = _sinon.default.spy();

    var wrapper = getWrapper({
      onShowMore: onShowMore
    });
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().handleShowMore();
    expect(onShowMore.calledOnce).toBe(true);
  });
  test('should render correct content in show more button', function () {
    var wrapper = getWrapper({
      showMoreButtonContent: 'content'
    });
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.setState({
      isOverflowing: true
    });
    expect(wrapper.find(_.Button).childAt(0).text()).toBe('content');
  });
});