"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Component = Spinner;
Object.defineProperty(exports, "styles", {
  enumerable: true,
  get: function get() {
    return _spinnerStyles.default;
  }
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactJss = _interopRequireDefault(require("react-jss"));

var _classnames = _interopRequireDefault(require("classnames"));

var _spinnerStyles = _interopRequireDefault(require("./spinner-styles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function generateRgb(degree, limit) {
  var multiplier = 255 / limit;
  var value = Math.round(degree * multiplier, 10);
  return "rgb(".concat(value, ", ").concat(value, ", ").concat(value, ")");
}

function conicalGradient(size, limit, clipPathId) {
  var sectionSize = size / 2;
  var gradientSectionsA = [];
  var gradientSectionsB = [];
  var rotationMultiplier = 360 / limit;

  for (var i = 0; i < limit; i += 1) {
    var rotation = i * rotationMultiplier;

    var item = _react.default.createElement("rect", {
      key: rotation,
      width: sectionSize,
      height: sectionSize,
      fill: generateRgb(i, limit),
      x: sectionSize,
      transform: "rotate(".concat(rotation, " ").concat(sectionSize, " ").concat(sectionSize, ")")
    });

    if (i > limit / 2) {
      gradientSectionsB.push(item);
    } else {
      gradientSectionsA.push(item);
    }
  }

  return _react.default.createElement("g", {
    className: "spinner__gradient"
  }, _react.default.createElement("g", null, gradientSectionsA.map(function (section) {
    return section;
  })), _react.default.createElement("g", {
    clipPath: "url(#".concat(clipPathId, ")")
  }, gradientSectionsB.map(function (section) {
    return section;
  })));
}

function renderCircleAsHtml(radius, color, maskId) {
  return {
    __html: "<circle class=\"spinner__circle\" cx=\"".concat(radius, "\" cy=\"").concat(radius, "\" r=\"").concat(radius, "\" fill=\"").concat(color, "\" mask=\"url(#").concat(maskId, ")\"></circle>")
  };
}

function Spinner(_ref) {
  var classes = _ref.classes,
      className = _ref.className,
      size = _ref.size,
      color = _ref.color,
      gradientStops = _ref.gradientStops,
      strokeWidth = _ref.strokeWidth,
      style = _ref.style,
      theme = _ref.theme,
      sheet = _ref.sheet,
      rest = _objectWithoutProperties(_ref, ["classes", "className", "size", "color", "gradientStops", "strokeWidth", "style", "theme", "sheet"]);

  var usedColor = color || theme.palette.cta;
  var stroke = strokeWidth || size / 8;
  var radius = size / 2;
  var maskId = "spinner__mask--".concat(size, "-").concat(stroke, "-").concat(gradientStops);
  var clipPathId = "spinner__clip-path--".concat(size);

  var wrapperStyle = _objectSpread({
    width: size,
    height: size
  }, style);

  return _react.default.createElement("span", _extends({}, rest, {
    className: (0, _classnames.default)(classes.spinner, className),
    style: wrapperStyle
  }), _react.default.createElement("svg", {
    className: classes.element,
    viewBox: "0 0 ".concat(size, " ").concat(size)
  }, _react.default.createElement("defs", null, _react.default.createElement("clipPath", {
    id: clipPathId
  }, _react.default.createElement("rect", {
    x: "0",
    y: "0",
    width: radius,
    height: size
  })), _react.default.createElement("mask", {
    id: maskId,
    maskUnits: "objectBoundingBox"
  }, _react.default.createElement("rect", {
    width: size,
    height: size,
    fill: "#FFFFFF"
  }), conicalGradient(size, gradientStops, clipPathId), _react.default.createElement("circle", {
    cx: radius,
    cy: radius,
    r: radius - stroke,
    fill: "#000000"
  }), _react.default.createElement("circle", {
    cx: radius,
    cy: stroke / 2,
    r: stroke / 2,
    fill: "#FFFFFF"
  }))), _react.default.createElement("g", {
    dangerouslySetInnerHTML: renderCircleAsHtml(radius, usedColor, maskId)
  })));
}

Spinner.defaultProps = {
  size: 16,
  gradientStops: 20
};
Spinner.propTypes = {
  classes: _propTypes.default.object.isRequired,
  theme: _propTypes.default.object.isRequired,
  className: _propTypes.default.string,
  size: _propTypes.default.number,
  color: _propTypes.default.string,
  gradientStops: _propTypes.default.number,
  strokeWidth: _propTypes.default.number,
  style: _propTypes.default.object
};

var _default = (0, _reactJss.default)(_spinnerStyles.default, {
  injectTheme: true
})(Spinner);

exports.default = _default;