"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _subsection = require("./subsection");

var _ = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('<Subsection />', function () {
  var classes = (0, _.mockClasses)(_subsection.styles);
  var defaultProps = {
    classes: classes,
    title: function title() {
      return _react.default.createElement("span", null, "Title");
    },
    theme: {
      transitions: {
        duration: {
          shorter: 200
        }
      }
    }
  };
  var clock;
  beforeEach(function () {
    clock = _sinon.default.useFakeTimers();
  });
  afterEach(function () {
    clock.restore();
  });
  test('should have the class root', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, defaultProps));
    expect(wrapper.hasClass(classes.root)).toBe(true);
  });
  test('should render two custom icons', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, _extends({
      icon: _.Icon.Trash
    }, defaultProps)));
    expect(wrapper.find(_.Icon.Trash)).toHaveLength(2);
  });
  test('should render one custom icon with class desktopOnly', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, _extends({
      icon: _.Icon.Trash
    }, defaultProps)));
    expect(wrapper.find(".".concat(classes.icon, ".").concat(classes.desktopOnly))).toHaveLength(1);
  });
  test('should render one custom icon with class mobileOnly', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, _extends({
      icon: _.Icon.Trash
    }, defaultProps)));
    expect(wrapper.find(".".concat(classes.icon, ".").concat(classes.mobileOnly))).toHaveLength(1);
  });
  test('should set toggleActive while animating when toggled prop is changed', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, defaultProps));
    wrapper.setProps({
      toggled: true
    });
    var toggleActive = wrapper.state('toggleActive');
    expect(toggleActive).toBe(true);
  });
  test('should unset toggleActive when animation is complete after toggled prop is changed', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, defaultProps));
    var before = wrapper.state('toggleActive');
    wrapper.setProps({
      toggled: true
    });
    clock.tick(500);
    var after = wrapper.state('toggleActive');
    expect(before).toBe(false);
    expect(after).toBe(false);
  });
  test('should change toggled state when toggled prop is changed', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, defaultProps));
    var before = wrapper.state('toggled');
    wrapper.setProps({
      toggled: !before
    });
    clock.tick(500);
    var after = wrapper.state('toggled');
    expect(after).not.toBe(before);
  });
  test('should not change toggled state when toggled prop is same', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, defaultProps));
    var before = wrapper.state('toggled');
    wrapper.setProps({
      toggled: before
    });
    var after = wrapper.state('toggled');
    expect(after).toBe(before);
  });
  test('hides the chevron when loading is true', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_subsection.Component, _extends({}, defaultProps, {
      loading: true
    })));
    var chevron = wrapper.find(".".concat(classes.chevron));
    expect(chevron).toHaveLength(0);
  });
});