"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _tab = require("./tab");

var _ = require("../../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var classes = (0, _.mockClasses)(_tab.styles);
var defaultProps = {
  classes: classes,
  children: 'label',
  selected: false,
  variant: 'primary',
  index: 0
};

var renderComponent = function renderComponent(props) {
  return (0, _enzyme.shallow)(_react.default.createElement(_tab.Component, _extends({}, defaultProps, props)));
};

describe('<Tab />', function () {
  test('should render <li> as container', function () {
    var wrapper = renderComponent();
    var actual = wrapper.type();
    var expected = 'li';
    expect(actual).toBe(expected);
  });
  test('should render role as presentation', function () {
    var wrapper = renderComponent();
    var actual = wrapper.props().role;
    var expected = 'presentation';
    expect(actual).toBe(expected);
  });
  test('should render correct classes', function () {
    var wrapper = renderComponent({
      variant: 'secondary'
    });
    var actual = wrapper.hasClass("".concat(classes.root, " ").concat(classes.secondary));
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should render a button', function () {
    var wrapper = renderComponent({
      singlePanel: true
    });
    var actual = wrapper.find('button').length;
    var expected = 1;
    expect(actual).toBe(expected);
  });
  test('should render a link', function () {
    var wrapper = renderComponent({
      singlePanel: false
    });
    var actual = wrapper.find('a').length;
    var expected = 1;
    expect(actual).toBe(expected);
  });
  test('should render default href to link', function () {
    var wrapper = renderComponent({
      singlePanel: false,
      index: 3
    });
    var actual = wrapper.find('a').props().href;
    var expected = '#tabs-tab-3';
    expect(actual).toBe(expected);
  });
  test('should override default href to link', function () {
    var wrapper = renderComponent({
      singlePanel: false,
      index: 3,
      href: '#special'
    });
    var actual = wrapper.find('a').props().href;
    var expected = '#special';
    expect(actual).toBe(expected);
  });
  test('should render a id', function () {
    var wrapper = renderComponent({
      index: 2
    });
    var actual = wrapper.find('a').props().id;
    var expected = 'tabs-tab-2';
    expect(actual).toBe(expected);
  });
  test('should render correct class', function () {
    var wrapper = renderComponent({
      index: 2
    });
    var actual = wrapper.find('a').hasClass(classes.tab);
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should have role as tab', function () {
    var wrapper = renderComponent({
      index: 2
    });
    var actual = wrapper.find('a').props().role;
    var expected = 'tab';
    expect(actual).toBe(expected);
  });
  test('should have type button if element is a button', function () {
    var wrapper = renderComponent({
      index: 1,
      singlePanel: true
    });
    var actual = wrapper.find('button').props().type;
    var expected = 'button';
    expect(actual).toBe(expected);
  });
  test('should not have type button if element is a link', function () {
    var wrapper = renderComponent({
      index: 1,
      singlePanel: false
    });
    var actual = wrapper.find('a').props().type;
    var expected = null;
    expect(actual).toBe(expected);
  });
  test('should have aria-selected set to true', function () {
    var wrapper = renderComponent({
      index: 1,
      selected: true
    });
    var actual = wrapper.find('a').props()['aria-selected'];
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should have aria-selected set to false', function () {
    var wrapper = renderComponent({
      index: 1,
      selected: false
    });
    var actual = wrapper.find('a').props()['aria-selected'];
    var expected = false;
    expect(actual).toBe(expected);
  });
  test('should have onClick callback', function () {
    var spy = _sinon.default.spy();

    var wrapper = renderComponent({
      index: 1,
      changeHandler: spy
    });
    wrapper.find('a').simulate('click', {
      preventDefault: function preventDefault() {}
    });
    expect(spy.calledOnce).toBe(true);
  });
  test('should render content', function () {
    var wrapper = renderComponent({
      index: 1,
      children: 'tab label'
    });
    var actual = wrapper.find('a').childAt(0).text();
    var expected = 'tab label';
    expect(actual).toBe(expected);
  });
});