"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _tabs = require("./tabs");

var _tab = _interopRequireDefault(require("./tab/tab"));

var _tabpanel = _interopRequireDefault(require("./tabpanel/tabpanel"));

var _ = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var classes = (0, _.mockClasses)(_tabs.styles);
var defaultProps = {
  classes: classes,
  value: 0
};

var renderComponent = function renderComponent(props) {
  return (0, _enzyme.shallow)(_react.default.createElement(_tabs.Component, _extends({}, defaultProps, props), _react.default.createElement(_tab.default, null, "Tab1"), _react.default.createElement(_tab.default, null, "Tab2"), _react.default.createElement(_tabpanel.default, null, "Tab1 content"), _react.default.createElement(_tabpanel.default, null, "Tab2 content")));
};

describe('<Tabs />', function () {
  test('should render div as container', function () {
    var wrapper = renderComponent();
    var actual = wrapper.type();
    var expected = 'div';
    expect(actual).toBe(expected);
  });
  test('should render ul', function () {
    var wrapper = renderComponent();
    var actual = wrapper.find('ul').length;
    var expected = 1;
    expect(actual).toBe(expected);
  });
  test('should render variant class', function () {
    var wrapper = renderComponent({
      variant: 'tertiary'
    });
    var actual = wrapper.find('ul').hasClass(classes.tertiary);
    expect(actual).toBe(true);
  });
  test('should render role tablist', function () {
    var wrapper = renderComponent();
    var actual = wrapper.find('ul').props().role;
    var expected = 'tablist';
    expect(actual).toBe(expected);
  });
  test('should render class from props', function () {
    var wrapper = renderComponent({
      className: 'test'
    });
    var actual = wrapper.find('ul').hasClass('test');
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should render two tabs inside tablist', function () {
    var wrapper = renderComponent();
    var actual = wrapper.find('ul[role="tablist"]').find(_tab.default).length;
    var expected = 2;
    expect(actual).toBe(expected);
  });
  test('should render two tabpanels', function () {
    var wrapper = renderComponent();
    var actual = wrapper.find(_tabpanel.default).length;
    var expected = 2;
    expect(actual).toBe(expected);
  });
  test('value prop should set what tab is selected', function () {
    var wrapper = renderComponent({
      value: 1
    });
    var actual = wrapper.find(_tab.default).at(1).props().selected;
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('value prop should set what tabpanel is selected', function () {
    var wrapper = renderComponent({
      value: 1
    });
    var actual = wrapper.find(_tabpanel.default).at(1).props().selected;
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should give tab index prop', function () {
    var wrapper = renderComponent();
    var actual = wrapper.find(_tab.default).at(1).props().index;
    var expected = 1;
    expect(actual).toBe(expected);
  });
  test('should give tabpanel index prop', function () {
    var wrapper = renderComponent();
    var actual = wrapper.find(_tabpanel.default).at(0).props().index;
    var expected = 0;
    expect(actual).toBe(expected);
  });
  test('should give tab variant prop', function () {
    var wrapper = renderComponent({
      variant: 'secondary'
    });
    var actual = wrapper.find(_tab.default).first().props().variant;
    var expected = 'secondary';
    expect(actual).toBe(expected);
  });
  test('should give tabpanel variant prop', function () {
    var wrapper = renderComponent({
      variant: 'secondary'
    });
    var actual = wrapper.find(_tabpanel.default).last().props().variant;
    var expected = 'secondary';
    expect(actual).toBe(expected);
  });
  test('should give tab singlePanel prop', function () {
    var wrapper = renderComponent({
      singlePanel: true
    });
    var actual = wrapper.find(_tab.default).first().props().singlePanel;
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should give tabpanel singlePanel prop', function () {
    var wrapper = renderComponent({
      singlePanel: true
    });
    var actual = wrapper.find(_tabpanel.default).last().props().singlePanel;
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should give tab onChange prop', function () {
    var callback = function callback() {};

    var wrapper = renderComponent({
      onChange: callback
    });
    var actual = wrapper.find(_tab.default).first().props().changeHandler;
    expect(actual).toBe(callback);
  });
  test('should not give tabpanel onChange prop', function () {
    var callback = function callback() {};

    var wrapper = renderComponent({
      onChange: callback
    });
    var actual = wrapper.find(_tabpanel.default).first().props().changeHandler;
    var expected = null;
    expect(actual).toBe(expected);
  });
});