"use strict";

var _react = _interopRequireDefault(require("react"));

var _sinon = _interopRequireDefault(require("sinon"));

var _enzyme = require("enzyme");

var _ = require("../..");

var _tooltip = require("./tooltip");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Tooltip />', function () {
  var classes = (0, _.mockClasses)(_tooltip.styles);
  var wrapper;
  beforeEach(function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_tooltip.Component, {
      classes: classes,
      content: "Lorem ipsum dolor sit amet."
    }));
  });
  test('should render <div> as container', function () {
    expect(wrapper.type()).toBe('div');
  });
  test('should not show the tooltip as default', function () {
    expect(wrapper.state('hover')).toBe(false);
    expect(wrapper.state('toggled')).toBe(false);
  });
  test('should show the tooltip when hovered', function () {
    wrapper.find(".".concat(classes.tooltip)).simulate('mouseEnter');
    expect(wrapper.state('hover')).toBe(true);
    wrapper.find(".".concat(classes.tooltip)).simulate('mouseLeave');
    expect(wrapper.state('hover')).toBe(false);
  });
  test('should toggle the tooltip when clicked', function () {
    wrapper.find(".".concat(classes.container)).simulate('click');
    expect(wrapper.state('toggled')).toBe(true);
  });
  test('should not display tooltip when clicked and sticky is false', function () {
    wrapper.setProps({
      sticky: false
    });
    wrapper.find(".".concat(classes.container)).simulate('click');
    expect(wrapper.state('toggled')).toBe(false);
  });
  test('should display tooltip when clicked and sticky is true', function () {
    wrapper.setProps({
      sticky: true
    });
    wrapper.find(".".concat(classes.container)).simulate('click');
    expect(wrapper.state('toggled')).toBe(true);
  });
  test('should have fixedWidth', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_tooltip.Component, {
      classes: classes,
      fixedWidth: 345,
      content: "Lorem ipsum dolor sit amet."
    }));
    wrapper.find(".".concat(classes.container)).simulate('mouseEnter');
    expect(wrapper.find(".".concat(classes.popupFixed)).prop('style')).toHaveProperty('width', 345);
  });
  test('should set className to above', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_tooltip.Component, {
      classes: classes,
      content: "Lorem ipsum dolor sit amet.",
      placement: "above"
    }));
    wrapper.find(".".concat(classes.container)).simulate('mouseEnter');
    expect(wrapper.find(".".concat(classes.popup)).hasClass('above')).toBe(true);
  });
  test('should set className to left', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_tooltip.Component, {
      classes: classes,
      content: "Lorem ipsum dolor sit amet.",
      placement: "left"
    }));
    wrapper.find(".".concat(classes.container)).simulate('mouseEnter');
    expect(wrapper.find(".".concat(classes.popup)).hasClass('left')).toBe(true);
  });
  test('should set placement to below if none is given', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_tooltip.Component, {
      classes: classes,
      content: "Lorem ipsum dolor sit amet."
    }));
    wrapper.find(".".concat(classes.container)).simulate('mouseEnter');
    expect(wrapper.find(".".concat(classes.popup)).hasClass('below')).toBe(true);
  });
  test('should set desktopOnly', function () {
    wrapper = (0, _enzyme.shallow)(_react.default.createElement(_tooltip.Component, {
      classes: classes,
      content: "Lorem ipsum dolor sit amet.",
      desktopOnly: true
    }));
    wrapper.find(".".concat(classes.container)).simulate('mouseEnter');
    expect(wrapper.find(".".concat(classes.popup)).hasClass(classes.popupDesktopOnly)).toBe(true);
  });
  describe('click outside functionality', function () {
    var target = {
      attachTo: document.getElementById('app')
    };
    var component;
    var sandbox;
    var addEventSpy;
    var removeEventSpy;
    beforeEach(function () {
      sandbox = _sinon.default.createSandbox();
      addEventSpy = sandbox.spy(document, 'addEventListener');
      removeEventSpy = sandbox.spy(document, 'removeEventListener');
      component = (0, _enzyme.mount)(_react.default.createElement(_tooltip.Component, {
        classes: classes,
        content: "abc"
      }, _react.default.createElement("div", {
        id: "child"
      }, "child")), target);
    });
    afterEach(function () {
      sandbox.restore();
    });
    test('should subscribe to click event on mount', function () {
      expect(addEventSpy.calledWith('click', component.instance().handleClick)).toBe(true);
    });
    test('should unsubscribe from click events on unmount', function () {
      var handleClick = component.instance().handleClick;
      component.unmount();
      expect(removeEventSpy.calledWith('click', handleClick)).toBe(true);
    });
    test('should untoggle tooltip when clicked outside', function () {
      component.find(".".concat(classes.container)).simulate('click');
      document.body.click();
      expect(component.state('toggled')).toBe(false);
    });
    test('should not untoggle tooltip when clicked inside', function () {
      component.find(".".concat(classes.container)).simulate('click');
      component.find(".".concat(classes.popupContent)).simulate('click');
      expect(component.state('toggled')).toBe(true);
    });
  });
});