"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createMixins;
var basicBoxSizing = {
  '&, & *, & *::after, & *::after': {
    boxSizing: 'border-box'
  }
};
var screenReadersOnly = {
  position: 'absolute',
  width: 1,
  height: 1,
  padding: 0,
  overflow: 'hidden',
  clip: 'rect(0,0,0,0)',
  whiteSpace: 'nowrap',
  clipPath: 'inset(50%)',
  border: 0
};

function createMixins() {
  var breakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var media = function media(size) {
    var breakpoint = breakpoints[size];

    if (breakpoint) {
      return "@media only screen and (min-width: ".concat(breakpoints[size], "px)");
    }

    return '&';
  };

  var maxMedia = function maxMedia(size) {
    var breakpoint = breakpoints[size];

    if (breakpoint) {
      return "@media only screen and (max-width: ".concat(breakpoints[size] - 1, "px)");
    }

    return '&';
  };

  return {
    basicBoxSizing: basicBoxSizing,
    media: media,
    maxMedia: maxMedia,
    screenReadersOnly: screenReadersOnly
  };
}