"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createTheme = createTheme;
exports.default = void 0;

var _transitions = _interopRequireDefault(require("./transitions"));

var _typography = _interopRequireDefault(require("./typography"));

var _breakpoints = _interopRequireDefault(require("./breakpoints"));

var _palette = require("./palette");

var _mixins = _interopRequireDefault(require("./mixins"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createTheme() {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var _config$palette = config.palette,
      palette = _config$palette === void 0 ? (0, _palette.createPalette)({
    type: 'dark',
    a11yColors: config.a11yColors
  }) : _config$palette,
      _config$breakpoints = config.breakpoints,
      breakpoints = _config$breakpoints === void 0 ? (0, _breakpoints.default)() : _config$breakpoints,
      _config$mixins = config.mixins,
      mixins = _config$mixins === void 0 ? (0, _mixins.default)(breakpoints) : _config$mixins,
      _config$typography = config.typography,
      typography = _config$typography === void 0 ? (0, _typography.default)() : _config$typography;
  var theme = {
    palette: palette,
    typography: typography,
    mixins: mixins,
    breakpoints: breakpoints,
    transitions: _transitions.default
  };
  return theme;
}

var _default = createTheme;
exports.default = _default;