function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { Component as Alert, styles } from './alert';
import { mockClasses, theme } from '../..';
var classes = mockClasses(styles);
var defaultProps = {
  classes: classes,
  theme: theme
};
describe('<Alert />', function () {
  test('should render <div> as container', function () {
    var wrapper = shallow(React.createElement(Alert, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.type();
    var expected = 'div';
    expect(actual).toBe(expected);
  });
  test('should have class alert', function () {
    var wrapper = shallow(React.createElement(Alert, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.hasClass(classes.alert);
    expect(actual).toBe(true);
  });
  ['success', 'warning', 'danger'].forEach(function (modifier) {
    test("should have class ".concat(classes[modifier], " if modifier is set to ").concat(modifier), function () {
      var wrapper = shallow(React.createElement(Alert, _extends({
        header: "header"
      }, defaultProps), "body"));
      wrapper.setProps({
        modifier: modifier
      });
      var actual = wrapper.hasClass("".concat(classes[modifier]));
      expect(actual).toBe(true);
    });
  });
  test('should render the header if provided', function () {
    var wrapper = shallow(React.createElement(Alert, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.find("div.".concat(classes.header)).childAt(0).text();
    var expected = 'header';
    expect(actual).toBe(expected);
  });
  test('should render the children if provided', function () {
    var wrapper = shallow(React.createElement(Alert, _extends({
      header: "header"
    }, defaultProps), "body"));
    var actual = wrapper.find("div.".concat(classes.body)).childAt(0).text();
    var expected = 'body';
    expect(actual).toBe(expected);
  });
  test('should close if the dismiss button is clicked', function () {
    var wrapper = shallow(React.createElement(Alert, _extends({
      header: "header"
    }, defaultProps), "body"));
    wrapper.find("button.".concat(classes.close)).simulate('click');
    var actual = wrapper.html();
    var expected = null;
    expect(actual).toBe(expected);
  });
  test('should not render the dismiss button if dismissable is set to false', function () {
    var wrapper = shallow(React.createElement(Alert, _extends({
      header: "header"
    }, defaultProps), "body"));
    wrapper.setProps({
      dismissable: false
    });
    var actual = wrapper.find("button.".concat(classes.close)).exists();
    expect(actual).toBe(false);
  });
  test('should call dismissedCallback when dismissed', function () {
    var spy = sinon.spy();
    var wrapper = shallow(React.createElement(Alert, _extends({}, defaultProps, {
      dismissedCallback: spy
    }), "body"));
    wrapper.find("button.".concat(classes.close)).simulate('click');
    expect(spy.calledOnce).toBe(true);
  });
  test('should not call dismissedCallback when not dismissed', function () {
    var spy = sinon.spy();
    shallow(React.createElement(Alert, _extends({}, defaultProps, {
      dismissedCallback: spy
    }), "body"));
    expect(spy.called).toBe(false);
  });
});