import React from 'react';
import PropTypes from 'prop-types';
import injectSheet from 'react-jss';
import cn from 'classnames';
import { CSSTransition, TransitionGroup } from 'react-transition-group';
import easings from '../../styles/transitions/easings';
import durations from '../../styles/transitions/durations';

var zeroHeight = function zeroHeight() {
  return 0;
};

var getEstimatedHeight = function getEstimatedHeight(props) {
  return props.estimatedHeight;
};

var initialHeight = {
  maxHeight: zeroHeight
};
var styles = {
  height: {
    boxSizing: 'border-box',
    transitionProperty: 'max-height, height'
  },
  heightEnter: initialHeight,
  heightEnterActive: {
    maxHeight: getEstimatedHeight,
    transitionTimingFunction: function transitionTimingFunction(props) {
      return props.easingEnterFunction;
    },
    transitionDuration: function transitionDuration(props) {
      return props.enterTime;
    },
    overflow: 'hidden'
  },
  heightExit: {
    maxHeight: getEstimatedHeight,
    transitionTimingFunction: function transitionTimingFunction(props) {
      return props.easingLeaveFunction;
    },
    transitionDuration: function transitionDuration(props) {
      return props.leaveTime;
    },
    overflow: 'hidden'
  },
  heightExitActive: initialHeight
};

var items = function items(children, classNameProp, classNames, timeout) {
  return children.map(function (child) {
    return React.createElement(CSSTransition, {
      key: child.key,
      className: classNameProp,
      classNames: classNames,
      timeout: timeout
    }, React.createElement("div", null, child));
  });
};

function Animate(_ref) {
  var classes = _ref.classes,
      className = _ref.className,
      children = _ref.children,
      type = _ref.type,
      enterTime = _ref.enterTime,
      leaveTime = _ref.leaveTime;
  var classNameProp = cn(classes[type], className);
  var classNames = {
    enter: classes["".concat(type, "Enter")],
    enterActive: classes["".concat(type, "EnterActive")],
    exit: classes["".concat(type, "Exit")],
    exitActive: classes["".concat(type, "ExitActive")]
  };
  var timeout = {
    enter: enterTime,
    exit: leaveTime
  };
  return React.createElement(TransitionGroup, null, items(React.Children.toArray(children), classNameProp, classNames, timeout));
}

Animate.propTypes = {
  classes: PropTypes.object.isRequired,
  children: PropTypes.node,
  className: PropTypes.string,
  type: PropTypes.oneOf(['height']),
  enterTime: PropTypes.number,
  leaveTime: PropTypes.number,
  easingEnterFunction: PropTypes.string,
  easingLeaveFunction: PropTypes.string,
  estimatedHeight: PropTypes.number
};
Animate.defaultProps = {
  type: 'height',
  enterTime: durations.shorter,
  leaveTime: durations.shorter,
  easingEnterFunction: easings.easeIn,
  easingLeaveFunction: easings.easeOut,
  estimatedHeight: 500
};
export { Animate as Component, styles };
export default injectSheet(styles)(Animate);