import React from 'react';
import { shallow } from 'enzyme';
import { mockClasses } from '../..';
import { Component as Button, styles } from './button';
describe('<Button />', function () {
  var classes = mockClasses(styles);
  var wrapper;
  test('should render <button> by default', function () {
    wrapper = shallow(React.createElement(Button, {
      classes: classes
    }, "Button"));
    expect(wrapper.type()).toBe('button');
  });
  ['primary', 'secondary', 'link'].forEach(function (variant) {
    test("should have class ".concat(classes[variant], " if variant is set to ").concat(variant), function () {
      wrapper = shallow(React.createElement(Button, {
        classes: classes,
        variant: variant
      }, "Button"));
      expect(wrapper.hasClass(classes[variant])).toBe(true);
    });
  });
  ['danger', 'warning', 'success'].forEach(function (modifier) {
    test("should have class ".concat(modifier, " if modifier is set to ").concat(modifier), function () {
      wrapper = shallow(React.createElement(Button, {
        classes: classes,
        modifier: modifier
      }, "Button"));
      expect(wrapper.hasClass(modifier)).toBe(true);
    });
  });
  test('should render children', function () {
    wrapper = shallow(React.createElement(Button, {
      classes: classes
    }, "Button"));
    expect(wrapper.childAt(0).text()).toBe('Button');
  });
  test('should be disabled if prop disabled is set', function () {
    wrapper = shallow(React.createElement(Button, {
      classes: classes,
      disabled: true
    }, "Button"));
    expect(wrapper.props().disabled).toBe(true);
  });
  test("should have class icon for an icon button", function () {
    var icon = React.createElement("svg", null);
    wrapper = shallow(React.createElement(Button, {
      classes: classes,
      icon: icon
    }));
    expect(wrapper.hasClass(classes.icon)).toBe(true);
  });
  test("should have class iconText for a button with an icon", function () {
    var icon = React.createElement("svg", null);
    wrapper = shallow(React.createElement(Button, {
      classes: classes,
      icon: icon
    }, "Button"));
    expect(wrapper.hasClass(classes.iconText)).toBe(true);
  });
});