import React from 'react';
import { shallow } from 'enzyme';
import { deprecatedProps, deprecatedComponent } from './deprecate';
var warnMock;
beforeEach(function () {
  warnMock = jest.fn();
  global.console.warn = warnMock;
});
var DEFAULT_MESSAGE = 'Please consult the docs for a migration guide.';
test('deprecatedComponent', function () {
  var Component = function Component() {
    return React.createElement("div", null);
  };

  var DC = deprecatedComponent('Flag')(Component);
  shallow(React.createElement(DC, null));
  expect(warnMock).toHaveBeenCalled();
  expect(warnMock.mock.calls[0][0]).toMatch('Flag is deprecated.');
  expect(warnMock.mock.calls[0][0]).toMatch(DEFAULT_MESSAGE);
});
test('deprecatedComponent with custom message', function () {
  var Component = function Component() {
    return React.createElement("div", null);
  };

  var msg = 'Use the new Flag component instead.';
  var DC = deprecatedComponent('Flag2', msg)(Component);
  shallow(React.createElement(DC, null));
  expect(warnMock).toHaveBeenCalled();
  expect(warnMock.mock.calls[0][0]).toMatch('Flag2 is deprecated.');
  expect(warnMock.mock.calls[0][0]).toMatch(msg);
});
test('deprecatedComponent should only warn once', function () {
  var Component = function Component() {
    return React.createElement("div", null);
  };

  var DC = deprecatedComponent('Flag3')(Component);
  shallow(React.createElement(DC, null));
  expect(warnMock).toHaveBeenCalled();
  shallow(React.createElement(DC, null));
  expect(warnMock).toHaveBeenCalledTimes(1);
  expect(warnMock.mock.calls[0][0]).toMatch('Flag3 is deprecated.');
});
test('deprecatedProps', function () {
  var Component = function Component() {
    return React.createElement("div", null);
  };

  var DC = deprecatedProps('Flag', [{
    prop: 'size',
    message: 'size in Flag as a number is deprecated. Use sm, md or lg instead'
  }])(Component);
  shallow(React.createElement(DC, {
    size: 16
  }));
  expect(warnMock).toHaveBeenCalled();
  expect(warnMock.mock.calls[0][0]).toMatch('Use sm, md or lg instead');
});