function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import PropTypes from 'prop-types';
import React from 'react';
import { withTheme } from 'react-jss';
import { SvgFlag, CurrencyFlag } from './flags';
import FlagDeprecated from './flag-deprecated';
import { deprecatedProps } from '../deprecate';

var addBorder = function addBorder(props) {
  return !props.hideBorder && !props.round && !props.secondaryCountryCode;
};

var Flag = function Flag(props) {
  var borderColor = props.borderColor ? props.borderColor : props.theme.palette.gray7;

  var extendedStyle = _objectSpread({}, props.style, {
    border: addBorder(props) ? "1px solid ".concat(borderColor) : null,
    backgroundColor: addBorder(props) ? borderColor : 'rgba(0,0,0,0)'
  });

  if (typeof props.size === 'number') {
    return React.createElement(FlagDeprecated, _extends({}, props, {
      style: extendedStyle
    }));
  }

  var className = props.className,
      style = props.style,
      countryCode = props.countryCode,
      secondaryCountryCode = props.secondaryCountryCode,
      size = props.size,
      round = props.round,
      hideBorder = props.hideBorder,
      rest = _objectWithoutProperties(props, ["className", "style", "countryCode", "secondaryCountryCode", "size", "round", "hideBorder"]);

  if (secondaryCountryCode) {
    return React.createElement(CurrencyFlag, {
      className: className,
      style: extendedStyle,
      size: size,
      primaryCC: countryCode.toLowerCase(),
      secondaryCC: secondaryCountryCode.toLowerCase()
    });
  }

  return React.createElement(SvgFlag, _extends({
    className: className,
    round: round,
    size: size,
    countryCode: countryCode.toLowerCase(),
    style: extendedStyle
  }, rest));
};

Flag.defaultProps = {
  countryCode: '',
  size: 32,
  round: false,
  hideBorder: false,
  borderColor: null
};
var countryCodes = ['ca', 'de', 'fr', 'ru', 'gb', 'dk', 'fi', 'no', 'se', 'us', 'jp', 'cn', 'eu', 'CA', 'DE', 'FR', 'RU', 'GB', 'DK', 'FI', 'NO', 'SE', 'US', 'JP', 'CN', 'EU'];
Flag.propTypes = {
  className: PropTypes.string,
  countryCode: PropTypes.oneOf(countryCodes),
  secondaryCountryCode: PropTypes.oneOf(countryCodes),
  size: PropTypes.oneOfType([PropTypes.number, PropTypes.oneOf(['xs', 'sm', 'md', 'lg'])]),
  style: PropTypes.object,
  round: PropTypes.bool,
  hideBorder: PropTypes.bool,
  borderColor: PropTypes.string,
  theme: PropTypes.shape()
};
export { Flag as Component };
export default deprecatedProps('Flag', [{
  prop: 'size',
  message: "size in Flag as a number is deprecated. Please use one of 'xs', 'sm', 'md', 'lg' instead"
}])(withTheme(Flag));