function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import Color from 'color';
export default (function (theme) {
  var palette = theme.palette,
      transitions = theme.transitions,
      mixins = theme.mixins,
      typography = theme.typography;

  var disabledColor = function disabledColor(color) {
    return Color(color).mix(Color(palette.gray4), 0.6).hex();
  };

  var inputMarginBottom = 20;
  var borderSize = 1;
  var bottomBorderSize = 1;

  var modifierFn = function modifierFn(color) {
    return {
      marginBottom: function marginBottom(_ref) {
        var label = _ref.label,
            helpText = _ref.helpText;
        return label || helpText ? inputMarginBottom : 0;
      },
      '& .input__label': {
        color: color
      },
      '& .input__field': {
        borderBottom: "".concat(bottomBorderSize, "px solid ").concat(color),
        marginBottom: function marginBottom(_ref2) {
          var label = _ref2.label,
              helpText = _ref2.helpText;
          return label && helpText && helpText.length > 32 ? inputMarginBottom : 0;
        }
      },
      '&--is-disabled': {
        '& .input': {
          '&__label': {
            color: disabledColor(color)
          },
          '&__field': {
            borderBottom: "".concat(bottomBorderSize, "px solid ").concat(disabledColor(color))
          }
        }
      }
    };
  };

  var modifierFocusFn = function modifierFocusFn(color) {
    return {
      '& .input': {
        '&__label': {
          color: color
        },
        '&__field': {
          borderColor: color,
          borderBottom: "".concat(bottomBorderSize, "px solid ").concat(color)
        }
      }
    };
  };

  return {
    input: _objectSpread({}, mixins.basicBoxSizing, {
      color: palette.gray0,
      marginBottom: function marginBottom(_ref3) {
        var label = _ref3.label;
        return bottomBorderSize - borderSize + (label ? inputMarginBottom : 0);
      },
      position: 'relative',
      '&.input--has-success': modifierFn(palette.positive),
      '&.input--has-warning': modifierFn(palette.negative),
      '&.input--has-error': _objectSpread({
        '& .input': {
          '&__label': {
            color: palette.negative,
            opacity: 1,
            transform: 'translateY(15px)'
          }
        }
      }, modifierFn(palette.negative)),
      '&.input--has-focus': {
        marginBottom: function marginBottom(_ref4) {
          var label = _ref4.label;
          return label ? inputMarginBottom : 0;
        },
        '& .input': {
          '&__label': {
            color: palette.cta,
            opacity: 1,
            transform: 'translateY(15px)'
          },
          '&__field': {
            borderColor: palette.cta,
            borderBottom: "1px solid ".concat(palette.cta)
          }
        },
        '&.input--has-success': modifierFocusFn(palette.positive),
        '&.input--has-warning': modifierFocusFn(palette.index),
        '&.input--has-error': modifierFocusFn(palette.negative)
      },
      '&.input--is-disabled': {
        color: palette.gray4,
        backgroundColor: palette.gray7,
        '& .input': {
          '&__label': {
            color: palette.gray4
          },
          '&__field': {
            borderColor: palette.gray4,
            '> input': {
              cursor: 'not-allowed'
            }
          }
        }
      },
      '&.input--has-addon': {
        '& .input': {
          '&__field': {
            display: 'flex',
            alignItems: 'baseline'
          },
          '&__element': {
            width: '100%'
          },
          '&__addon': _objectSpread({
            color: palette.gray0,
            '&--left': {
              left: 10,
              paddingRight: 8
            },
            '&--right': {
              right: 10,
              paddingLeft: 8
            }
          }, typography.tertiary())
        }
      },
      '& .input__label': _objectSpread({
        position: 'absolute',
        bottom: '-4px',
        left: 0,
        cursor: 'text',
        transition: transitions.create(['opacity', 'transform', 'color']),
        transform: 'translateY(0)',
        opacity: 0,
        color: palette.gray4,
        pointerEvents: 'none',
        '&.input--has-focus, &.input--has-value': {
          opacity: 1,
          transform: 'translateY(0)'
        }
      }, typography.tertiary()),
      '& .input__element': _objectSpread({
        display: 'block',
        background: 'none',
        border: 0,
        borderRadius: 0,
        width: '100%',
        transition: transitions.create(['border-color', 'transform']),
        height: '1.5em',
        minWidth: 0,
        padding: 0,
        '&:focus': {
          outline: 'none'
        },
        '&:invalid, &:-moz-ui-invalid': {
          boxShadow: 'none'
        },
        '&--textarea': {
          maxHeight: 'none',
          resize: 'vertical',
          height: function height(_ref5) {
            var lineCount = _ref5.lineCount;
            return "".concat(lineCount * 1.5, "em");
          }
        }
      }, typography.secondary()),
      '& .input__validation-icon': {
        position: 'absolute',
        display: 'block',
        right: 4,
        bottom: 10,
        height: 8,
        transition: transitions.create(),
        '> img': {
          display: 'block',
          maxHeight: '100%'
        }
      }
    }, typography.secondary()),
    primary: {
      '& .input__field': {
        position: 'relative',
        width: '100%',
        border: "".concat(borderSize, "px solid ").concat(palette.gray4),
        borderRadius: 0,
        padding: 8,
        paddingTop: 10,
        transition: transitions.create(['border-color'])
      }
    },
    secondary: {
      '& .input__field': {
        position: 'relative',
        width: '100%',
        padding: [8, 0],
        border: 'none',
        borderBottom: "".concat(borderSize, "px solid ").concat(palette.gray4),
        paddingTop: 10,
        transition: transitions.create(['border-color'])
      }
    }
  };
});