import PropTypes from 'prop-types';
import React from 'react';
import InputDefault from './input-default';
import InputSelect from './input-select';
import InputCheckboxRadio from './input-checkbox-radio';

function Input(props) {
  switch (props.type) {
    case 'select':
      return React.createElement(InputSelect, props);

    case 'checkbox':
    case 'radio':
      return React.createElement(InputCheckboxRadio, props);

    default:
      return React.createElement(InputDefault, props);
  }
}

Input.propTypes = {
  className: PropTypes.string,
  style: PropTypes.object,
  type: PropTypes.string,
  variant: PropTypes.oneOf(['primary', 'secondary']),
  disabled: PropTypes.bool,
  label: PropTypes.node,
  placeholder: PropTypes.string,
  id: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number, PropTypes.bool, PropTypes.array, PropTypes.object]),
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  lineCount: PropTypes.number,
  selectablePlaceholder: PropTypes.bool,
  valueFormatter: PropTypes.func,
  hasSuccess: PropTypes.bool,
  hasError: PropTypes.bool,
  hasWarning: PropTypes.bool,
  helpText: PropTypes.node,
  leftAddon: PropTypes.node,
  rightAddon: PropTypes.node
};
Input.defaultProps = {
  type: 'text',
  variant: 'primary'
};
export { Input as Component };
export default Input;