function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { shallow } from 'enzyme';
import { Component as Input } from './input';
import { Component as InputDefault, styles as inputDefaultStyles } from './input-default';
import { Component as InputSelect, styles as inputSelectStyles } from './input-select';
import { Component as InputCheckboxRadio, styles as inputCheckboxRadioStyles } from './input-checkbox-radio';
import HelpText from './help-text';
import { mockClasses, theme } from '../..';
var inputDefaultClasses = mockClasses(inputDefaultStyles);
var inputSelectClasses = mockClasses(inputSelectStyles);
var inputRadioClasses = mockClasses(inputCheckboxRadioStyles);

var classes = _objectSpread({}, inputDefaultClasses, inputSelectClasses, inputRadioClasses);

var defaultProps = {
  theme: theme,
  classes: classes,
  label: 'label',
  value: 'value',
  placeholder: 'placeholder'
};

var renderComponent = function renderComponent(_ref) {
  var _ref$Component = _ref.Component,
      Component = _ref$Component === void 0 ? Input : _ref$Component,
      props = _ref.props;
  return shallow(React.createElement(Component, _extends({}, defaultProps, props)));
};

describe('<Input />', function () {
  var wrapper;
  var inputTypes = [{
    name: 'text',
    componentName: 'InputDefault',
    component: InputDefault
  }, {
    name: 'select',
    componentName: 'InputSelect',
    component: InputSelect
  }, {
    name: 'checkbox',
    componentName: 'InputCheckboxRadio',
    component: InputCheckboxRadio
  }, {
    name: 'radio',
    componentName: 'InputCheckboxRadio',
    component: InputCheckboxRadio
  }];
  inputTypes.forEach(function (type) {
    describe("with type=".concat(type.name), function () {
      beforeEach(function () {
        wrapper = renderComponent({
          Component: type.component,
          props: type.componentName === 'InputCheckboxRadio' ? {
            type: type.name
          } : {}
        });
      });
      test("should render an <".concat(type.componentName, " />"), function () {
        wrapper = renderComponent({
          props: {
            type: type.name
          }
        });
        expect(wrapper.type().InnerComponent).toBe(type.component);
      });

      if (type.componentName !== 'InputCheckboxRadio') {
        test("should have class ".concat(classes.input), function () {
          expect(wrapper.hasClass(classes.input)).toBe(true);
        });
        test('should print the label if text is entered', function () {
          expect(wrapper.find('Label').shallow().childAt(0).text()).toBe('label');
        });
        test('should set the placeholder to the property placeholder', function () {
          if (type.component === InputSelect) {
            var wrapperWithoutValue = renderComponent({
              Component: type.component,
              props: {
                value: undefined
              }
            });
            expect(wrapperWithoutValue.find('FakePlaceholder').prop('placeholder')).toBe('placeholder');
          } else {
            expect(wrapper.find('NativeInput').prop('placeholder')).toBe('placeholder');
          }
        });
        test('should have class input--has-error if error', function () {
          wrapper.setProps({
            hasError: true
          });
          expect(wrapper.hasClass('input--has-error')).toBe(true);
        });
        test('should have class input--has-success if success', function () {
          wrapper.setProps({
            hasSuccess: true
          });
          expect(wrapper.hasClass('input--has-success')).toBe(true);
        });
      } else {
        test("should have class ".concat(classes['input-checkbox-radio']), function () {
          expect(wrapper.find(".".concat(classes['input-checkbox-radio']))).toHaveLength(1);
        });
        test('should have class input-checkbox-radio--has-error if error', function () {
          wrapper.setProps({
            hasError: true
          });
          expect(wrapper.find('.input-checkbox-radio--has-error')).toHaveLength(1);
        });
        test('should have class input-checkbox-radio--has-success if success', function () {
          wrapper.setProps({
            hasSuccess: true
          });
          expect(wrapper.find('.input-checkbox-radio--has-success')).toHaveLength(1);
        });
        test('should be unchecked by default', function () {
          expect(wrapper.find("input[type=\"".concat(type.name, "\"]")).prop('checked')).toBe(false);
        });
        test('should be checked if checked in props', function () {
          wrapper.setProps({
            checked: true
          });
          expect(wrapper.find("input[type=\"".concat(type.name, "\"]")).prop('checked')).toBe(true);
        });
        test('should become checked if unchecked and clicked', function () {
          wrapper.find("input[type=\"".concat(type.name, "\"]")).simulate('change', {
            target: {
              checked: true
            },
            currentTarget: {
              checked: true
            }
          });
          expect(wrapper.find("input[type=\"".concat(type.name, "\"]")).prop('checked')).toBe(true);
        });
        test('should render helptext if specified', function () {
          wrapper.setProps({
            helpText: 'help'
          });
          expect(wrapper.find(HelpText).childAt(0).text()).toBe('help');
        });
      }

      if (type.name === 'text') {
        test('should have class input--text', function () {
          expect(wrapper.hasClass('input--text')).toBe(true);
        });
      } else if (type.name === 'select') {
        test('should have class input--select', function () {
          expect(wrapper.hasClass('input--select')).toBe(true);
        });
      }
    });
  });
});