import React from 'react';
import { shallow } from 'enzyme';
import { Component as InstrumentBadge, styles } from './instrument-badge';
import Checkmark from '../icon/icons/checkmark';
import ExclamationPoint from '../icon/icons/exclamationPoint';
import { mockClasses, theme } from '../..';
describe('<InstrumentBadge />', function () {
  var classes = mockClasses(styles);
  var wrapper;
  test('should render <div> as container', function () {
    wrapper = shallow(React.createElement(InstrumentBadge, {
      classes: classes,
      theme: theme
    }));
    expect(wrapper.type()).toBe('div');
  });
  test('should adapt classes to size small', function () {
    wrapper = shallow(React.createElement(InstrumentBadge, {
      classes: classes,
      size: "sm",
      theme: theme
    }));
    expect(wrapper.find(".".concat(classes.sm))).toHaveLength(1);
    expect(wrapper.find(".".concat(classes.md))).toHaveLength(0);
  });
  test('should adapt classes to size medium', function () {
    wrapper = shallow(React.createElement(InstrumentBadge, {
      classes: classes,
      size: "md",
      theme: theme
    }));
    expect(wrapper.find(".".concat(classes.sm))).toHaveLength(0);
    expect(wrapper.find(".".concat(classes.md))).toHaveLength(1);
  });
  test('should render checkmark icon when marked as qualified', function () {
    wrapper = shallow(React.createElement(InstrumentBadge, {
      qualified: true,
      classes: classes,
      theme: theme
    }));
    expect(wrapper.find(Checkmark)).toHaveLength(1);
    expect(wrapper.find(ExclamationPoint)).toHaveLength(0);
  });
  test('should render ExclamationPoint icon when NOT marked as qualified', function () {
    wrapper = shallow(React.createElement(InstrumentBadge, {
      classes: classes,
      theme: theme
    }));
    expect(wrapper.find(Checkmark)).toHaveLength(0);
    expect(wrapper.find(ExclamationPoint)).toHaveLength(1);
  });
  test('should render instrument level and subtext', function () {
    wrapper = shallow(React.createElement(InstrumentBadge, {
      subText: "Qualified!",
      classes: classes,
      theme: theme
    }));
    expect(wrapper.find(".".concat(classes.subText)).text()).toBe('Qualified!');
  });
});