function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import injectSheet from 'react-jss';
import cn from 'classnames';
import { kebabCase } from 'lodash';
var modifiers = {
  xs: 14,
  sm: 14,
  md: 20,
  lg: 32,
  xlg: 48
};
var mobileModifiers = {
  xs: 12,
  sm: 14,
  md: 16,
  lg: 24,
  xlg: 28
};
export var styles = function styles(theme) {
  var palette = theme.palette,
      typography = theme.typography,
      mixins = theme.mixins;
  var valueSizes = Object.keys(modifiers).reduce(function (sizes, size) {
    var fontSize = modifiers[size];
    var mobileFontSize = mobileModifiers[size];
    var paddingTop = size === 'xs' ? 0 : 2;
    var className = "value-".concat(size);
    return _objectSpread({}, sizes, _defineProperty({}, className, _defineProperty({
      fontSize: mobileFontSize,
      paddingTop: paddingTop
    }, theme.mixins.media('md'), {
      fontSize: fontSize
    })));
  }, {});
  return _objectSpread({
    root: _objectSpread({}, mixins.basicBoxSizing, {
      display: 'inline-block',
      color: palette.gray0,
      fontFamily: typography.primary.fontFamily
    }),
    label: _objectSpread({
      display: 'block'
    }, typography.secondary(), {
      color: palette.gray2
    }),
    value: _objectSpread({
      display: 'block'
    }, typography.primary())
  }, valueSizes);
};

function LabeledValue(_ref) {
  var classes = _ref.classes,
      label = _ref.label,
      children = _ref.children,
      idProp = _ref.id,
      className = _ref.className,
      size = _ref.size,
      theme = _ref.theme,
      sheet = _ref.sheet,
      rest = _objectWithoutProperties(_ref, ["classes", "label", "children", "id", "className", "size", "theme", "sheet"]);

  var id = idProp || "".concat(kebabCase(label), "-label");
  var rootClasses = cn(classes.root, className);
  var labelClasses = cn(classes.label);
  var valueClasses = cn(classes.value, classes["value-".concat(size)]);
  return React.createElement("div", _extends({}, rest, {
    className: rootClasses
  }), React.createElement("span", {
    className: labelClasses,
    id: id
  }, label), React.createElement("span", {
    className: valueClasses,
    "aria-labelledby": id
  }, children));
}

LabeledValue.defaultProps = {
  label: '',
  children: '',
  size: 'md'
};
LabeledValue.propTypes = {
  classes: PropTypes.object.isRequired,
  label: PropTypes.node,
  children: PropTypes.node,
  id: PropTypes.string,
  className: PropTypes.string,
  size: PropTypes.oneOf(['xs', 'sm', 'md', 'lg', 'xlg'])
};
export { LabeledValue as Component };
export default injectSheet(styles, {
  injectTheme: true
})(LabeledValue);