function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import { mockClasses } from '../../..';
import { Component as Page, styles } from './page';
import ButtonNode from '../button-node';
describe('<Page />', function () {
  var classes = mockClasses(styles);
  var defaultProps = {
    classes: classes,
    isSelected: false,
    isFirst: false,
    isLast: false,
    pageNumber: 2,
    labelText: '',
    url: '',
    selectHandler: function selectHandler() {}
  };

  var shallowComponent = function shallowComponent(customProps) {
    return shallow(React.createElement(Page, _extends({}, defaultProps, customProps)));
  };

  test('should render a li element', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find("li.".concat(classes.item))).toHaveLength(1);
  });
  test('should render a li element with class itemAlwaysVisible if page is selected', function () {
    var wrapper = shallowComponent({
      isSelected: true
    });
    expect(wrapper.find("li.".concat(classes.item)).hasClass(classes.itemAlwaysVisible)).toBe(true);
  });
  test('should render a li element with class itemAlwaysVisible if page is first', function () {
    var wrapper = shallowComponent({
      isFirst: true
    });
    expect(wrapper.find("li.".concat(classes.item)).hasClass(classes.itemAlwaysVisible)).toBe(true);
  });
  test('should render a li element with class itemAlwaysVisible if page is last', function () {
    var wrapper = shallowComponent({
      isLast: true
    });
    expect(wrapper.find("li.".concat(classes.item)).hasClass(classes.itemAlwaysVisible)).toBe(true);
  });
  test('should render a ButtonNode component', function () {
    var wrapper = shallowComponent({
      isLast: true
    });
    expect(wrapper.find(ButtonNode)).toHaveLength(1);
  });
  test('should render disabled prop to ButtonNode component', function () {
    var wrapper = shallowComponent({
      isSelected: true
    });
    expect(wrapper.find(ButtonNode).props().disabled).toBe(true);
  });
  test('should not render disabled prop to ButtonNode component', function () {
    var wrapper = shallowComponent({
      isSelected: false
    });
    expect(wrapper.find(ButtonNode).props().disabled).toBe(false);
  });
  test('should render url prop to ButtonNode component', function () {
    var wrapper = shallowComponent({
      url: 'www.test.com'
    });
    expect(wrapper.find(ButtonNode).props().url).toBe('www.test.com');
  });
  test('should have getNode prop in ButtonNode component', function () {
    var testFunc = function testFunc() {
      return true;
    };

    var wrapper = shallowComponent({
      getNode: testFunc
    });
    expect(wrapper.find(ButtonNode).props().getNode).toBe(testFunc);
  });
  test('should have aria-label text in defaultProps', function () {
    var wrapper = shallowComponent({
      labelText: 'Go to page'
    });
    expect(wrapper.find(ButtonNode).props().defaultProps['aria-label']).toBe('Go to page');
  });
});