function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { mockClasses, Icon } from '../..';
import { Component as Pagination, styles } from './pagination';
import Stepper from './stepper';
import Range from './range';
describe('<Pagination />', function () {
  var classes = mockClasses(styles);
  var defaultProps = {
    classes: classes,
    total: 100,
    limit: 10,
    buttonTextPrevious: 'Previous',
    buttonTextNext: 'Next',
    urlGenerator: function urlGenerator() {
      return null;
    }
  };

  var shallowComponent = function shallowComponent(customProps) {
    return shallow(React.createElement(Pagination, _extends({}, defaultProps, customProps)));
  };

  test('should not paginate if there is only 1 page', function () {
    var wrapper = shallowComponent({
      total: 10,
      limit: 10
    });
    expect(wrapper.find("ul.".concat(classes.list))).toHaveLength(0);
  });
  test('should render a nav element', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find('nav')).toHaveLength(1);
  });
  test('should render next and previous buttons', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper)).toHaveLength(2);
  });
  test('previous button should not be clickable', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper).first().prop('disabled')).toBe(true);
  });
  test('previous button should be clickable', function () {
    var wrapper = shallowComponent({
      selected: 2
    });
    expect(wrapper.find(Stepper).first().prop('disabled')).toBe(false);
  });
  test('next button should not be clickable', function () {
    var wrapper = shallowComponent({
      selected: 10
    });
    expect(wrapper.find(Stepper).last().prop('disabled')).toBe(true);
  });
  test('next button should be clickable', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper).last().prop('disabled')).toBe(false);
  });
  test('next button should render text', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper).last().find(".".concat(classes.stepperText)).childAt(0).text()).toBe(defaultProps.buttonTextNext);
  });
  test('next button should render SVG', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper).last().find(Icon.ArrowRight)).toHaveLength(1);
  });
  test('previous button should render text', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper).first().find(".".concat(classes.stepperText)).childAt(0).text()).toBe(defaultProps.buttonTextPrevious);
  });
  test('previous button should render SVG', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Stepper).first().find(Icon.ArrowLeft)).toHaveLength(1);
  });
  test('should render a range of pages', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Range)).toHaveLength(1);
  });
  test('should increment selected in state', function () {
    var clickCallback = sinon.spy();
    var wrapper = shallowComponent({
      changeHandler: clickCallback
    });
    wrapper.find(Stepper).last().props().clickHandler();
    expect(wrapper.state().selected).toBe(2);
  });
  test('should decrement selected in state', function () {
    var clickCallback = sinon.spy();
    var wrapper = shallowComponent({
      changeHandler: clickCallback,
      selected: 2
    });
    wrapper.find(Stepper).first().props().clickHandler();
    expect(wrapper.state().selected).toBe(1);
  });
  test('should increment selected in state when prop changes', function () {
    var clickCallback = sinon.spy();
    var selected = 1;
    var wrapper = shallowComponent({
      selected: selected,
      changeHandler: clickCallback
    });
    wrapper.setProps({
      selected: selected + 1
    });
    expect(wrapper.state().selected).toBe(selected + 1);
  });
  test('should decrement selected in state when prop changes', function () {
    var clickCallback = sinon.spy();
    var selected = 2;
    var wrapper = shallowComponent({
      selected: selected,
      changeHandler: clickCallback
    });
    wrapper.setProps({
      selected: selected - 1
    });
    expect(wrapper.state().selected).toBe(selected - 1);
  });
});