function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import { mockClasses } from '../../..';
import { Component as Range, styles } from './range';
import Page from '../page';
import Ellipsis from '../ellipsis';
describe('<Range />', function () {
  var classes = mockClasses(styles);
  var defaultProps = {
    classes: classes,
    anchors: 1,
    pagesCount: 10,
    selected: 1,
    selectedSiblings: 2,
    urlGenerator: function urlGenerator() {
      return null;
    }
  };

  var shallowComponent = function shallowComponent(customProps) {
    return shallow(React.createElement(Range, _extends({}, defaultProps, customProps)));
  };

  test('should render a ul element', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find("ul.".concat(classes.list))).toHaveLength(1);
  });
  test('should render 5 pages', function () {
    var wrapper = shallowComponent({
      pagesCount: 5
    });
    expect(wrapper.find(Page)).toHaveLength(5);
  });
  test('should render one ellipsis', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Ellipsis)).toHaveLength(1);
  });
  test('should render two ellipsis', function () {
    var wrapper = shallowComponent({
      selected: 5
    });
    expect(wrapper.find(Ellipsis)).toHaveLength(2);
  });
  test('should mark page as selected', function () {
    var wrapper = shallowComponent({
      selected: 3
    });
    expect(wrapper.find(Page).at(2).props().isSelected).toBe(true);
  });
  test('first page should have prop isFirst', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Page).first().props().isFirst).toBe(true);
  });
  test('first page should not have prop isLast', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Page).first().props().isLast).toBe(false);
  });
  test('last page should have prop isLast', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Page).last().props().isLast).toBe(true);
  });
  test('last page should not have prop isFirst', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Page).last().props().isFirst).toBe(false);
  });
  test('page should have false on the prop isFirst', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Page).at(2).props().isFirst).toBe(false);
  });
  test('page should have false on the prop isLast', function () {
    var wrapper = shallowComponent();
    expect(wrapper.find(Page).at(2).props().isLast).toBe(false);
  });
  test('render label text for page', function () {
    var wrapper = shallowComponent({
      selected: 2,
      pageLabelText: 'go to page',
      pageLebelSelected: 'current page'
    });
    expect(wrapper.find(Page).first().props().labelText).toBe('go to page 1');
  });
  test('render label text for selected page', function () {
    var wrapper = shallowComponent({
      selected: 1,
      pageLabelText: 'go to page',
      pageLabelTextSelected: 'current page'
    });
    expect(wrapper.find(Page).first().props().labelText).toBe('current page 1');
  });
});