import React from 'react';
import { shallow } from 'enzyme';
import { mockClasses } from '../..';
import { Component as Pane, styles } from './pane';
describe('<Pane />', function () {
  var classes = mockClasses(styles);
  describe('When <Pane /> don´t have any tabs', function () {
    var wrapper = shallow(React.createElement(Pane, {
      classes: classes
    }));
    test('should render null', function () {
      expect(wrapper.type()).toBeNull();
    });
  });
  describe('When <Pane /> is correctly populated with default props', function () {
    var tabs = [{
      label: 'Tab 1',
      body: React.createElement("div", null, "This is tab 1!")
    }, {
      label: 'Tab 2',
      body: React.createElement("div", null, "This is tab 2!")
    }, {
      label: 'Tab 3',
      body: React.createElement("div", null, "This is tab 3!")
    }];
    var wrapper;
    var renderedTabs;
    beforeEach(function () {
      wrapper = shallow(React.createElement(Pane, {
        classes: classes,
        tabs: tabs
      }));
      renderedTabs = wrapper.children().children().find('li');
    });
    test('should render <div> as container', function () {
      expect(wrapper.type()).toBe('div');
    });
    test('should have the class pane', function () {
      expect(wrapper.hasClass(classes.pane)).toBe(true);
    });
    test('should render children', function () {
      expect(wrapper.children()).toHaveLength(2);
    });
    test('should render tabs', function () {
      expect(renderedTabs).toHaveLength(3);
    });
    test('should have first tab as active', function () {
      expect(renderedTabs.at(0).hasClass(classes.active)).toBe(true);
    });
    test('default size should be md', function () {
      expect(renderedTabs.at(0).hasClass(classes.md)).toBe(true);
    });
  });
  describe('When <Pane /> is correctly populated with another size', function () {
    var tabs = [{
      label: 'Tab 1',
      body: React.createElement("div", null, "This is tab 1!")
    }];
    var wrapper = shallow(React.createElement(Pane, {
      classes: classes,
      tabs: tabs,
      size: "lg"
    }));
    test('should render <div> as container', function () {
      expect(wrapper.type()).toBe('div');
    });
    test('should have the class pane', function () {
      expect(wrapper.hasClass(classes.pane)).toBe(true);
    });
    test('should have class lg', function () {
      expect(wrapper.children().children().find('li').at(0).hasClass(classes.lg)).toBe(true);
    });
  });
});