function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { mockClasses } from '../..';
import { styles } from './popup-menu';
import { Component as PopupMenuItem, styles as itemStyles } from './popup-menu-item';
import PopupMenuList from './popup-menu-list';
import keyCodes from './keyCodes';
describe('<PopupMenuList />', function () {
  var classes = mockClasses(styles);
  var itemClasses = mockClasses(itemStyles);
  var props = {
    onBlur: function onBlur() {},
    onKeyDown: function onKeyDown() {},
    firstListItemRef: function firstListItemRef() {},
    yieldFocus: function yieldFocus() {},
    width: 200,
    'aria-labelledby': 'PopupMenu',
    enter: 100,
    exit: 100,
    maxHeight: 'none'
  };
  test('should not render the list if isOpen is false', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: false
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    expect(wrapper.find(PopupMenuItem)).toHaveLength(0);
  });
  test('should render the list if isOpen is true', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    expect(wrapper.find(PopupMenuItem)).toHaveLength(1);
  });
  test('should update focusIndex if list item is focused', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    expect(instance.focusIndex).toBe(-1);
    wrapper.find(PopupMenuItem).first().prop('onFocus')();
    expect(instance.focusIndex).toBe(0);
  });
  test('should focus next item on arrow down', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    wrapper.find(PopupMenuItem).first().prop('onFocus')();
    expect(instance.focusIndex).toBe(0);
    instance.onKeyDown({
      keyCode: keyCodes.ARROW_DOWN,
      preventDefault: function preventDefault() {}
    });
    expect(instance.focusIndex).toBe(1);
  });
  test('should focus previous item on arrow up', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    wrapper.find(PopupMenuItem).last().prop('onFocus')();
    expect(instance.focusIndex).toBe(1);
    instance.onKeyDown({
      keyCode: keyCodes.ARROW_UP,
      preventDefault: function preventDefault() {}
    });
    expect(instance.focusIndex).toBe(0);
  });
  test('should wrap to first item on arrow down on last item', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    instance.listItemElements = [{
      focus: function focus() {}
    }, {
      focus: function focus() {}
    }];
    wrapper.find(PopupMenuItem).last().prop('onFocus')();
    expect(instance.focusIndex).toBe(1);
    instance.onKeyDown({
      keyCode: keyCodes.ARROW_DOWN,
      preventDefault: function preventDefault() {}
    });
    expect(instance.focusIndex).toBe(0);
  });
  test('should blur item on esc', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var instance = wrapper.instance();
    var blur = sinon.spy();
    instance.listItemElements = [{}, {
      focus: function focus() {},
      blur: blur
    }];
    wrapper.find(PopupMenuItem).last().prop('onFocus')();
    expect(instance.focusIndex).toBe(1);
    instance.onKeyDown({
      keyCode: keyCodes.ESC,
      preventDefault: function preventDefault() {}
    });
    expect(blur.calledOnce).toBe(true);
  });
  test('should not add the focus handling props to disabled children', function () {
    var wrapper = shallow(React.createElement(PopupMenuList, _extends({}, props, {
      classes: classes,
      isOpen: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses,
      disabled: true
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var items = wrapper.find(PopupMenuItem);
    var nonDisabledItems = items.findWhere(function (i) {
      return i.prop('listItemRef') && i.prop('onFocus') && i.prop('onKeyDown');
    });
    var disabledItems = items.findWhere(function (i) {
      return !i.prop('listItemRef') && !i.prop('onFocus') && !i.prop('onKeyDown');
    });
    expect(nonDisabledItems).toHaveLength(2);
    expect(disabledItems).toHaveLength(1);
  });
});