import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { mockClasses } from '../..';
import { Component as PopupMenu, styles } from './popup-menu';
import { Component as PopupMenuItem, styles as itemStyles } from './popup-menu-item';
import PopupMenuList from './popup-menu-list';
import keyCodes from './keyCodes';
describe('<PopupMenu />', function () {
  var classes = mockClasses(styles);
  var itemClasses = mockClasses(itemStyles);
  var wrapper;
  test('should render <span> by default', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    expect(wrapper.type()).toBe('span');
  });
  test('should render a button and a PopupMenuList as its children', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    expect(wrapper.find("button.".concat(classes.menuButton))).toHaveLength(1);
    expect(wrapper.find(PopupMenuList)).toHaveLength(1);
  });
  test('renders correct amount of PopupMenuItems', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    expect(wrapper.find('PopupMenuItem')).toHaveLength(3);
  });
  test('should not be focused by default', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    expect(wrapper.state('hasFocus')).toBe(false);
  });
  test('should set hasFocus to true on toggle button focus', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    wrapper.find("button.".concat(classes.menuButton)).simulate('focus');
    expect(wrapper.state('hasFocus')).toBe(true);
  });
  test('should set hasFocus to false on toggle button blur', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    wrapper.find("button.".concat(classes.menuButton)).simulate('focus');
    wrapper.find("button.".concat(classes.menuButton)).simulate('blur');
    expect(wrapper.state('hasFocus')).toBe(false);
  });
  test('should focus first list element and prevent default on arrow down', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    }), React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var focus = sinon.spy();
    var preventDefault = sinon.spy();
    wrapper.instance().firstListElement = {
      focus: focus
    };
    wrapper.find("button.".concat(classes.menuButton)).simulate('focus');
    wrapper.find("button.".concat(classes.menuButton)).simulate('click');
    wrapper.find("button.".concat(classes.menuButton)).simulate('keyDown', {
      preventDefault: preventDefault,
      keyCode: keyCodes.ARROW_DOWN
    });
    expect(focus.calledOnce).toBe(true);
    expect(preventDefault.calledOnce).toBe(true);
  });
  test('should toggle on esc press', function () {
    var onToggle = sinon.spy();
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes,
      onToggle: onToggle
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    wrapper.find("button.".concat(classes.menuButton)).simulate('click');
    wrapper.find("button.".concat(classes.menuButton)).simulate('keyDown', {
      keyCode: keyCodes.ESC
    });
    expect(onToggle.calledTwice).toBe(true);
  });
  test('should take focus when PopupMenuList yields focus', function () {
    wrapper = shallow(React.createElement(PopupMenu, {
      classes: classes
    }, React.createElement(PopupMenuItem, {
      classes: itemClasses
    })));
    var focus = sinon.spy();
    wrapper.instance().buttonElement = {
      focus: focus
    };
    var yieldFocusCallback = wrapper.find(PopupMenuList).prop('yieldFocus');
    yieldFocusCallback();
    expect(focus.calledOnce).toBe(true);
  });
});