import React from 'react';
import { shallow } from 'enzyme';
import { mockClasses } from '../..';
import { Component as ProgressBar, styles } from './progress-bar';
describe('<ProgressBar />', function () {
  var classes = mockClasses(styles);
  var value = 3;
  var max = 5;
  var wrapper;
  test('should render as primary by default', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    expect(wrapper.find('.progressBar').childAt(0).hasClass(classes.primary)).toBe(true);
  });
  test('should render steps as spans by default', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    expect(wrapper.find('.progressBar').childAt(0).type()).toBe('span');
  });
  test('should not print numbers by default', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    expect(wrapper.find('.progressBar').childAt(0).text()).toBe('');
  });
  test('should be able to print numbers', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      printNumbers: true
    }));
    expect(wrapper.find('.progressBar').childAt(0).text()).toBe('1');
  });
  test('should render the correct number of steps', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    expect(wrapper.find('.progressBar').children()).toHaveLength(max);
  });
  test('should render the correct number of reached steps', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    [0, 1, 2].forEach(function (step) {
      expect(wrapper.find('.progressBar').childAt(step).hasClass('reached')).toBe(true);
    });
  });
  test('should render the correct number of unreached steps', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    [3, 4].forEach(function (step) {
      expect(wrapper.find('.progressBar').childAt(step).hasClass('reached')).toBe(false);
    });
  });
  test('should not highlight the active step by default', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max
    }));
    expect(wrapper.find('.progressBar .active')).toHaveLength(0);
    expect(wrapper.find('.progressBar').childAt(value - 1).hasClass('active')).toBe(false);
  });
  test('should be possible to highlight the active step', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      highlightActive: true
    }));
    expect(wrapper.find('.progressBar .active')).toHaveLength(1);
    expect(wrapper.find('.progressBar').childAt(value - 1).hasClass('active')).toBe(true);
  });
  ['primary'].forEach(function (variant) {
    test("should have class ".concat(classes[variant], " if variant is set to ").concat(variant), function () {
      wrapper = shallow(React.createElement(ProgressBar, {
        classes: classes,
        variant: variant,
        value: value,
        max: max
      }));
      expect(wrapper.find('.progressBar').childAt(0).hasClass(classes[variant])).toBe(true);
    });
  });
  test('should be possible to render a step as an A tag', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      clickables: [{
        href: '/foo/bar'
      }]
    }));
    expect(wrapper.find('.progressBar').childAt(0).type()).toBe('a');
  });
  test('should be possible to render a step as a BUTTON tag', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      clickables: [{
        onClick: function onClick() {}
      }]
    }));
    expect(wrapper.find('.progressBar').childAt(0).type()).toBe('button');
  });
  test('should be possible to render a step as a disabled BUTTON tag', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      clickables: [{
        disabled: true
      }]
    }));
    expect(wrapper.find('.progressBar').childAt(0).type()).toBe('button');
    expect(wrapper.find('.progressBar').childAt(0).props().disabled).toBe(true);
  });
  test('should be possible to override the reached class for a specific step', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      clickables: [{
        reached: false
      }]
    }));
    expect(wrapper.find('.progressBar').childAt(0).hasClass('reached')).toBe(false);
    expect(wrapper.find('.progressBar').childAt(1).hasClass('reached')).toBe(true);
  });
  test('should be possible to override the active class for a specific step', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      clickables: [{
        active: true
      }]
    }));
    expect(wrapper.find('.progressBar').childAt(0).hasClass('reached')).toBe(true);
  });
  test('should be possible to override the label class for a specific step', function () {
    wrapper = shallow(React.createElement(ProgressBar, {
      classes: classes,
      value: value,
      max: max,
      printNumbers: true,
      clickables: [{
        label: 'A'
      }]
    }));
    expect(wrapper.find('.progressBar').childAt(0).text()).toBe('A');
    expect(wrapper.find('.progressBar').childAt(1).text()).toBe('2');
  });
});