function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { mockClasses } from '../..';
import { Component as RadioGroup, styles } from './radio-group';
var classes = mockClasses(styles);
var defaultProps = {
  classes: classes,
  value: 1,
  selectedValue: '1',
  name: 'radio-group',
  type: 'radio',
  children: [React.createElement("input", {
    key: "1",
    type: "radio",
    value: "1"
  })]
};

var renderComponent = function renderComponent(props) {
  return shallow(React.createElement(RadioGroup, _extends({}, defaultProps, props)));
};

describe('<RadioGroup />', function () {
  test('should render <div> as container', function () {
    var wrapper = renderComponent();
    var actual = wrapper.type();
    var expected = 'div';
    expect(actual).toBe(expected);
  });
  test('should give all children inputs the name attribute sent in as prop', function () {
    var name = 'this-is-the-default-name';
    var children = [React.createElement("input", {
      key: "1",
      type: "radio",
      value: "1"
    }), React.createElement("input", {
      key: "2",
      type: "radio",
      value: "2"
    })];
    var wrapper = renderComponent({
      name: name,
      children: children
    });
    var actual = wrapper.find("input[name=\"".concat(name, "\"]"));
    var expected = children.length;
    expect(actual).toHaveLength(expected);
  });
  test('should give each input the sameRow class', function () {
    var children = [React.createElement("input", {
      key: "1",
      type: "radio",
      value: "1"
    }), React.createElement("input", {
      key: "2",
      type: "radio",
      value: "2"
    })];
    var wrapper = renderComponent({
      children: children,
      orientation: 'horizontal'
    });
    var actual = wrapper.find("input[value=\"1\"]").prop('className');
    expect(actual).toContain(classes.sameRow);
  });
  test('should give each input except the last the margin class', function () {
    var children = [React.createElement("input", {
      key: "1",
      type: "radio",
      value: "1"
    }), React.createElement("input", {
      key: "2",
      type: "radio",
      value: "2"
    })];
    var wrapper = renderComponent({
      children: children,
      orientation: 'horizontal'
    });
    expect(wrapper.find("input[value=\"1\"]").prop('className')).toContain(classes.margin);
    expect(wrapper.find("input[value=\"2\"]").prop('className')).not.toContain(classes.margin);
  });
  test('should render the correct input as selected when selectedValue is supplied', function () {
    var selectedValue = '1';
    var children = [React.createElement("input", {
      key: "1",
      type: "radio",
      value: "1"
    }), React.createElement("input", {
      key: "2",
      type: "radio",
      value: "2"
    })];
    var wrapper = renderComponent({
      selectedValue: selectedValue,
      children: children
    });
    var actual = wrapper.find("input[value=\"".concat(selectedValue, "\"]")).prop('checked');
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should call user supplied onChange when an input is changed to checked', function () {
    var spy = sinon.spy();
    var wrapper = renderComponent({
      selectedValue: '1',
      onChange: spy,
      children: [React.createElement("input", {
        key: "1",
        type: "radio",
        value: "1"
      }), React.createElement("input", {
        key: "2",
        type: "radio",
        value: "2"
      })]
    });
    var actual = wrapper.find('input[type="radio"][value="2"]');
    actual.simulate('change', {
      target: {
        checked: true
      },
      currentTarget: {
        checked: true
      }
    });
    var expected = true;
    expect(spy.calledOnce).toBe(expected);
  });
});