function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { Component as SegmentedControl, styles } from './segmented-control';
import { mockClasses, theme } from '../..';
var classes = mockClasses(styles);
var defaultProps = {
  classes: classes,
  theme: theme,
  value: 1,
  name: 'segmented-control',
  type: 'radio',
  children: [React.createElement("span", {
    value: 1
  }, "1")]
};

var renderComponent = function renderComponent(props) {
  return shallow(React.createElement(SegmentedControl, _extends({}, defaultProps, props)));
};

describe('<SegmentedControl />', function () {
  test('should render <span> as container', function () {
    var wrapper = renderComponent();
    var actual = wrapper.type();
    var expected = 'span';
    expect(actual).toBe(expected);
  });
  test('should render two inputs with type radio when type="radio" and we give it 2 children', function () {
    var wrapper = renderComponent({
      type: 'radio',
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="radio"]');
    var expected = 2;
    expect(actual).toHaveLength(expected);
  });
  test('should render two inputs with type radio when type="checkbox" and we give it 2 children', function () {
    var wrapper = renderComponent({
      type: 'checkbox',
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="checkbox"]');
    var expected = 2;
    expect(actual).toHaveLength(expected);
  });
  test('should call user supplied onChange when an input with type radio is changed to checked', function () {
    var spy = sinon.spy();
    var wrapper = renderComponent({
      onChange: spy,
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="radio"][value=2]');
    actual.simulate('change', {
      target: {
        checked: true
      },
      currentTarget: {
        checked: true
      }
    });
    var expected = true;
    expect(spy.calledOnce).toBe(expected);
  });
  test('should call user supplied onChange when an input with type checkbox is changed to checked', function () {
    var spy = sinon.spy();
    var wrapper = renderComponent({
      onChange: spy,
      type: 'checkbox',
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="checkbox"][value=2]');
    actual.simulate('change', {
      target: {
        checked: true
      },
      currentTarget: {
        checked: true
      }
    });
    expect(spy.calledOnce).toBe(true);
  });
  test('should set state to true when an input with type checkbox is changed to checked', function () {
    var wrapper = renderComponent({
      type: 'checkbox',
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="checkbox"][value=2]');
    actual.simulate('change', {
      target: {
        checked: true
      },
      currentTarget: {
        value: 2
      }
    });
    expect(wrapper.state()[2]).toBe(true);
  });
  test('should set focus to child index when element get focus', function () {
    var wrapper = renderComponent({
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="radio"][value=1]');
    actual.simulate('focus', {
      type: 'focus'
    });
    expect(wrapper.state('focus')).toBe(0);
  });
  test('should set focus to empty value when element get focus but event is not focus', function () {
    var wrapper = renderComponent({
      children: [React.createElement("span", {
        value: 1
      }, "1"), React.createElement("span", {
        value: 2
      }, "2")]
    });
    var actual = wrapper.find('input[type="radio"][value=1]');
    actual.simulate('focus', {
      type: 'not focus'
    });
    expect(wrapper.state('focus')).toBe('');
  });
});