function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import sinon from 'sinon';
import { Component as ShowMore } from './show-more';
import styles from './show-more-styles';
import { Button, mockClasses } from '../..';
var classes = mockClasses(styles);
var defaultProps = {
  children: 'Children',
  classes: classes
};
var addEventListenerSpy;
var removeEventListenerSpy;

var getWrapper = function getWrapper() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return shallow(React.createElement(ShowMore, _extends({}, defaultProps, props)), {
    disableLifecycleMethods: true
  });
};

describe('<ShowMore />', function () {
  beforeEach(function () {
    addEventListenerSpy = sinon.spy(window, 'addEventListener');
    removeEventListenerSpy = sinon.spy(window, 'removeEventListener');
  });
  afterEach(function () {
    addEventListenerSpy.restore();
    removeEventListenerSpy.restore();
  });
  test('should render <div> as container', function () {
    var wrapper = getWrapper();
    var actual = wrapper.type();
    var expected = 'div';
    expect(actual).toBe(expected);
  });
  test('should not show button if content fits', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 500,
      clientHeight: 500
    };
    wrapper.instance().componentDidMount();
    expect(wrapper.state('isOverflowing')).toBe(false);
  });
  test('should show button if content does not fit', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().componentDidMount();
    expect(wrapper.state('isOverflowing')).toBe(true);
  });
  test('should register resize event listener on mount', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().componentDidMount();
    expect(addEventListenerSpy.args[0][0]).toBe('resize');
  });
  test('should not check if overflow when updated with same children', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    var checkIfOverflowingSpy = sinon.spy(wrapper.instance(), 'checkIfOverflowing');
    wrapper.instance().componentDidUpdate({
      children: 'Children'
    });
    expect(checkIfOverflowingSpy.notCalled).toBe(true);
  });
  test('should check if overflow when updated with new children', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    var checkIfOverflowingSpy = sinon.spy(wrapper.instance(), 'checkIfOverflowing');
    wrapper.instance().componentDidUpdate({
      children: 'new child'
    });
    expect(checkIfOverflowingSpy.calledOnce).toBe(true);
  });
  test('should deregister resize event listener on unmount', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().componentWillUnmount();
    expect(removeEventListenerSpy.args[0][0]).toBe('resize');
  });
  test('should set showMoreClicked to true when show more button is clicked', function () {
    var wrapper = getWrapper();
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().handleShowMore();
    expect(wrapper.state('showMoreClicked')).toBe(true);
  });
  test('should call user supplied onShowMore when show more button is clicked', function () {
    var onShowMore = sinon.spy();
    var wrapper = getWrapper({
      onShowMore: onShowMore
    });
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.instance().handleShowMore();
    expect(onShowMore.calledOnce).toBe(true);
  });
  test('should render correct content in show more button', function () {
    var wrapper = getWrapper({
      showMoreButtonContent: 'content'
    });
    wrapper.instance().descriptionContainer = {
      scrollHeight: 600,
      clientHeight: 500
    };
    wrapper.setState({
      isOverflowing: true
    });
    expect(wrapper.find(Button).childAt(0).text()).toBe('content');
  });
});