function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { shallow } from 'enzyme';
import { Component as Tabpanel, styles } from './tabpanel';
import { mockClasses } from '../../..';
var classes = mockClasses(styles);
var defaultProps = {
  classes: classes,
  children: 'label',
  selected: false,
  index: 0
};

var renderComponent = function renderComponent(props) {
  return shallow(React.createElement(Tabpanel, _extends({}, defaultProps, props)));
};

describe('<Tabpanel />', function () {
  test('should render section as container', function () {
    var wrapper = renderComponent();
    var actual = wrapper.type();
    var expected = 'section';
    expect(actual).toBe(expected);
  });
  test('should role tabpanel', function () {
    var wrapper = renderComponent({
      index: 0
    });
    var actual = wrapper.props().role;
    var expected = 'tabpanel';
    expect(actual).toBe(expected);
  });
  test('should render a default id', function () {
    var wrapper = renderComponent({
      index: 3
    });
    var actual = wrapper.props().id;
    var expected = 'tabs-tabpanel-3';
    expect(actual).toBe(expected);
  });
  test('should override default id', function () {
    var wrapper = renderComponent({
      index: 3,
      id: 'tabpanelid'
    });
    var actual = wrapper.props().id;
    var expected = 'tabpanelid';
    expect(actual).toBe(expected);
  });
  test('should have attribute aria-labelledby', function () {
    var wrapper = renderComponent({
      index: 2
    });
    var actual = wrapper.props()['aria-labelledby'];
    var expected = 'tabs-tab-2';
    expect(actual).toBe(expected);
  });
  test('should not have attribute aria-labelledby if singlePanel', function () {
    var wrapper = renderComponent({
      index: 2,
      singlePanel: true
    });
    var actual = wrapper.props()['aria-labelledby'];
    var expected = null;
    expect(actual).toBe(expected);
  });
  test('should have hidden attribute', function () {
    var wrapper = renderComponent({
      index: 2,
      selected: false
    });
    var actual = wrapper.props().hidden;
    var expected = true;
    expect(actual).toBe(expected);
  });
  test('should not have hidden attribute', function () {
    var wrapper = renderComponent({
      index: 2,
      selected: true
    });
    var actual = wrapper.props().hidden;
    var expected = false;
    expect(actual).toBe(expected);
  });
  test('should never have hidden attribute if singlePanel', function () {
    var wrapper = renderComponent({
      index: 2,
      selected: false,
      singlePanel: true
    });
    var actual = wrapper.props().hidden;
    var expected = null;
    expect(actual).toBe(expected);
  });
  test('should render content', function () {
    var wrapper = renderComponent({
      index: 1,
      children: 'test content'
    });
    var actual = wrapper.childAt(0).text();
    var expected = 'test content';
    expect(actual).toBe(expected);
  });
});