function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { breakpoints } from './breakpoints';
var SMALL_DEVICE = breakpoints.sm;
var WEIGHTS = {
  regular: 400,
  bold: 700,
  extrabold: 800
};
var FONT_FAMILY = '"Nordnet Sans Mono", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, sans-serif';
var commonFontStyles = {
  fontFamily: FONT_FAMILY,
  letterSpacing: 'normal'
};
export default function createTypography() {
  var ifSmallDevice = function ifSmallDevice(smallFontSize, largeFontSize) {
    return _objectSpread({}, commonFontStyles, _defineProperty({
      fontSize: smallFontSize
    }, "@media only screen and (min-width: ".concat(SMALL_DEVICE, "px)/* override fix */"), {
      fontSize: largeFontSize
    }));
  };

  var primary = function primary() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref$weight = _ref.weight,
        weight = _ref$weight === void 0 ? 'regular' : _ref$weight;

    return _objectSpread({}, commonFontStyles, {
      fontSize: 16,
      fontWeight: WEIGHTS[weight] || WEIGHTS.regular
    });
  };

  var coerceExtraboldToBold = function coerceExtraboldToBold(weight) {
    return weight === 'extrabold' ? WEIGHTS.bold : WEIGHTS[weight];
  };

  var secondary = function secondary() {
    var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref2$weight = _ref2.weight,
        weight = _ref2$weight === void 0 ? 'regular' : _ref2$weight;

    return _objectSpread({}, commonFontStyles, {
      fontSize: 14,
      fontWeight: coerceExtraboldToBold(weight) || WEIGHTS.regular
    });
  };

  var tertiary = function tertiary() {
    var _ref3 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref3$weight = _ref3.weight,
        weight = _ref3$weight === void 0 ? 'regular' : _ref3$weight;

    return _objectSpread({}, commonFontStyles, {
      fontSize: 12,
      fontWeight: coerceExtraboldToBold(weight) || WEIGHTS.regular
    });
  };

  var caption = function caption() {
    var _ref4 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref4$weight = _ref4.weight,
        weight = _ref4$weight === void 0 ? 'regular' : _ref4$weight,
        _ref4$uppercase = _ref4.uppercase,
        uppercase = _ref4$uppercase === void 0 ? false : _ref4$uppercase;

    return _objectSpread({}, commonFontStyles, {
      fontSize: 10,
      fontWeight: coerceExtraboldToBold(weight) || WEIGHTS.regular
    }, uppercase ? {
      textTransform: 'uppercase'
    } : {});
  };

  var hero = function hero() {
    return _objectSpread({}, ifSmallDevice(46, 48), {
      fontWeight: WEIGHTS.extrabold
    });
  };

  var defaultTitleWeight = 'extrabold';

  var title1 = function title1() {
    var _ref5 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref5$weight = _ref5.weight,
        weight = _ref5$weight === void 0 ? defaultTitleWeight : _ref5$weight;

    return _objectSpread({}, ifSmallDevice(24, 28), {
      fontWeight: WEIGHTS[weight] || WEIGHTS[defaultTitleWeight]
    });
  };

  var title2 = function title2() {
    var _ref6 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref6$weight = _ref6.weight,
        weight = _ref6$weight === void 0 ? defaultTitleWeight : _ref6$weight;

    return _objectSpread({}, ifSmallDevice(20, 24), {
      fontWeight: WEIGHTS[weight] || WEIGHTS[defaultTitleWeight]
    });
  };

  var title3 = function title3() {
    var _ref7 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref7$weight = _ref7.weight,
        weight = _ref7$weight === void 0 ? defaultTitleWeight : _ref7$weight;

    return _objectSpread({}, ifSmallDevice(18, 20), {
      fontWeight: WEIGHTS[weight] || WEIGHTS[defaultTitleWeight]
    });
  };

  var newTypography = {
    caption: caption,
    hero: hero,
    title1: title1,
    title2: title2,
    title3: title3,
    primary: primary,
    secondary: secondary,
    tertiary: tertiary
  };
  var proxyIsAvailable = typeof window !== 'undefined' ? 'Proxy' in window : true;
  var legacyTypographyKeys = ['fontFamilyOpen', 'fontFamilyBitter', 'fontSize', 'fontWeightLight', 'fontWeightRegular', 'fontWeightMedium', 'fontWeightSemiBold', 'fontWeightBold', 'fontWeightExtraBold'];
  return proxyIsAvailable ? new Proxy(newTypography, {
    get: function get(target, prop) {
      if (legacyTypographyKeys.includes(prop)) {
        console.error("Accessing ".concat(prop, " on old typography object"));
      }

      return target[prop];
    }
  }) : newTypography;
}